#!/usr/bin/php
<?php

// This script computes an estimate of the percentage of critical client
// data, & raises an alert if the percentage exceeds 45% of total capacity.
// See bugzilla 11110 for details.

// Set debug=true to get some messages.
$debug=false;
$bpdir = trim(shell_exec('eval `grep BPDIR /etc/default/bp.ini`; echo $BPDIR'));
$dbconn_string = "port=5432 dbname=bpdb user=postgres";

// Only process this alert if the platform supports deduplication.
exec("$bpdir/bin/platformSupportsDedup", $throwaway, $ret_code);
// The script returns non-zero if deduplication is supported.
if ($ret_code == 0) {
	// successful exit
	exit(0);
}

bp_bypass_cookie(3);
// Find the percentage threshold for raising the alert
// SRI is Space Reserve Index, old terminology from bptool -M
$ret = bp_get_ini_value("Alertman", "SRIthreshold");
if ($ret == false) {
	// The default is 45% if not set
	$threshold = 45;
}
else {
	$threshold = (int)$ret;
}

if ($debug) echo "Using percentage threshold of $threshold percent.\n";

// This can take a long time on a fully loaded system.
$ret = bp_get_retention_info();
if ($ret == false) {
	echo "Could not compute retention: ".bp_error()."\n";
	exit(1);
}

// Get the values from the retention output.
$used = $ret["used"];
$capacity = $ret["available"];

// Divide $used by 2 to account for estimated 2:1 compression
$criticalData = (($used / 2) * 100) / $capacity;
$criticalData = round($criticalData);

if ($debug) {
	echo "used: $used, capacity: $capacity, criticalData(%): $criticalData\n";
}

if ($criticalData > $threshold) {
	$msg = " or acquiring another appliance to accommodate this critical data";
	if ($debug) echo "Raising alert for CriticalDataThreshold.\n";

	if (bp_is_virtual()) {
		$msg = ", expanding your storage by adding a new virtual SCSI disk to this VM, then select Settings->Storage and Retention from the User Interface, " .
				"or adding more resources (virtual processors/memory) to the system";
	}

	bp_send_notification(95, "CriticalDataThreshold", $msg);
}
else {
	if ($debug) echo "Clear/resolve alert for CriticalDataThreshold.\n";
	bp_send_notification(52, "CriticalDataThreshold");
}

// The maximum backup capacity for an appliance is specified in
// platform_capabilities as max_backup:XXX where XXX is an integer in GB.
// If the critical client data exceeds this amount, raise an alert.
// See bugzilla 12247 for details.

// The model name is used in the alert/email text.
$model=exec("grep 'Unitrends DPU' /etc/unitrends-release | awk '{print $3}'");
if (empty($model)) {
	$model = "this appliance";
}
else {
	$model = "a $model";
}
if ($debug) echo "Model string: $model\n";

$max_backup = exec("$bpdir/bin/cmc_capabilities get max_backup", $throwaway,
		$ret_code);

if ($ret_code == 0 and $max_backup !== "false") {
	if ($debug) echo "max_backup is $max_backup\n";

	if ($used > $max_backup) {

		// This sends email every time...
		if ($debug) echo "Raising alert for max_backup exceeded.\n";
		$criticalData = round($used);
		bp_send_notification(109, "MaxBackupExceeded", "$criticalData GB",
				"$max_backup GB", $model);

		// Turn off hashing.
		$ini_val = bp_get_ini_value("fileDedup", "enableHashing");
		if ($debug) echo "enableHashing is $ini_val.\n";
		// Never mind checking all the other possible negative values,
		// just be sure to set it to No.
		if ($ini_val != "No") {
			if ($debug) echo "Setting enableHashing to No.\n";
			$ret_code = bp_set_ini_value("fileDedup", "enableHashing", "No");
		}
	}
	else if ($used < $max_backup) {
		if ($debug) echo "Clear/resolve alert for max_backup exceeded?\n";
		$dbconn = pg_connect($dbconn_string);
		if($dbconn === FALSE) {
			print "ERROR: Failed to connect to the database.\n";
			die(1);
		}
		$query = "SELECT closed::int FROM bp.alerts WHERE notification_id=109";
		$query .= " ORDER BY updated DESC LIMIT 1";
		if ($debug) echo "Query:\n $query\n";
		$res = pg_query($dbconn, $query);
		if ($res !== false and (pg_num_rows($res) > 0)) {
			$closed = pg_fetch_result($res, 0, "closed");
			if ($debug) echo "Alert found, closed=$closed\n";
			if ($closed == false) {
				$criticalData = round($used);
				bp_send_notification(110, "MaxBackupExceeded",
						"$criticalData GB", "$max_backup GB", $model);
				// Turn hashing back on.
				$ini_val = bp_get_ini_value("fileDedup", "enableHashing");
				if ($debug) echo "enableHashing is $ini_val.\n";
				// Never mind all possible values, just set it to Yes.
				if ($ini_val != "Yes") {
					if ($debug) echo "Setting enableHashing to Yes.\n";
					$ret_code = bp_set_ini_value("fileDedup", "enableHashing",
							"Yes");
				}
			}
		}
		else {
			if ($debug) echo "No open alert found for max_backup exceeded.\n";
		}
	}
}
else {
	// Not all platforms will have this setting...
	if ($debug) echo "max_backup not found in platform_capabilites\n";
}

bp_destroy_cookie();
exit(0);

?>

