#!/usr/bin/php
<?php

// This script is used to collect information primarily to expedite retrieval of system 
// information for remote managed systems when issuing get_systems API requests. In the
// future, additional information may be collected to support other APIs.
// 
// There are 2 aspects of this script: local collection and remote pulls from Targets. The
// frequency for each is the same and governed by cron. By default, the collection and pull
// occur every 15 minutes, as defined by a master.ini setting. This setting is checked every
// time this script runs.
//
// The information collected and the information pulled all leverage the sync_summary db table.
// Some local information collected is obtained from within this script (e.g. archive enabled, 
// installation version and progress), while others are populated by individual components
// (e.g. storage space, protected assets, and if newer versions available). The pulling of
// information occurs on Targets which connects to Sources they are managing and reads the
// content of the remote sync_summary table.


#### GLOBALS  #######

declare(ticks = 1); # required for signal handlers
$program_name   = basename($argv[0], ".php");
$debug          = false; # set this to true to get debug messages
$bploc          = trim(shell_exec('eval `grep BPDIR /etc/default/bp.ini`; echo $BPDIR'));
if (empty($bploc) === true) { $bploc = "/usr/bp"; }
$bpbin          = "$bploc/bin";
$loc_conn_str   = "port=5432 dbname=bpdb user=postgres connect_timeout=30";
$pid            = getmypid();
$child_pids     = array();
$master_ini     = "$bploc/bpinit/master.ini";
$crontab_bin    = "/usr/bin/crontab";
$def_frequency  = "15"; # mm
$vacuum_day     = 0; # Sunday
$dfl_vac_time   = "04:00"; # 4am
$dfl_pull_delay = 300; # 5 mins
$prog_started   = time(); # when the program started
$started        = time(); # after PullDelay, the is_active check_timestamp
$log_count      = 25;
$log            = "";
$unknown        = "unknown";
$latest         = "latest";
$in_progress    = "update_in_progress";
$update_avail   = "update_available";
$local_version  = 'Unknown';

#### GLOBALS  #######

function haveOpenAlert($localDBconn, $source, $target, $notify_id)
{
  $q = "SELECT * FROM bp.alerts WHERE source_id = ";
  $q .= "(SELECT source_id FROM bp.alert_source WHERE source_name = '$source') ";
  $q .= "AND target = '$target' AND closed = false AND notification_id = $notify_id";

  $r = pg_query($localDBconn, $q);
  if (!$r or pg_num_rows($r) == 0) {
	return false;
  }
  else {
	return pg_fetch_assoc($r, 0);
  }
}

function createAlertMsg($existing_alert)
{
	global $started;

  # see if there are old open alerts and calculate the time the system was down
  if ($existing_alert !== false) {
	  $time = $existing_alert['created'] - 60;
  }
  else {
	  $time = $started - 60; /* default to 1 minute down */
  }
  $seconds_down = $started - $time;
  $minutes_down = floor($seconds_down / 60);
  $hours_down = floor($minutes_down / 60);
  $days_down = floor($hours_down / 24);
  $rem_minutes_down = $minutes_down % 60;
  $rem_hours_down = $hours_down % 24;

  if ($days_down > 0) {
	  $str = "{$days_down}d {$rem_hours_down}h {$rem_minutes_down}m";
  }
  else {
	  $str = "{$hours_down}h {$rem_minutes_down}m";
  }
  return $str;
}

function updateInActive($localDbConn, $tgt_system_id_of_src, $name)
{
  global $log;
  global $started;
  global $debug;

  # update local system is_active and check_timestamp 
  $query = "UPDATE bp.systems SET is_active = false, check_timestamp = $started WHERE system_id = $tgt_system_id_of_src";
  if ($debug) print "Query: $query\n";
  $retval = pg_query($localDbConn, $query);
  if ($retval === false) {
    fprintf($log, "Updating bp.systems locally for inactive system $name failed\n");
  }

  # Raise or update the alert
  $existing_alert = haveOpenAlert($localDbConn, 'DPU', $name, 14);
  $str = createAlertMsg($existing_alert);
  # notify_id 14: "%s: cannot connect to DPU database. %s"
  bp_send_notification(14, $name, $name, "(Down: $str)");
  fprintf($log, "%s an alert for $name DB connectivity.\n", $existing_alert? "Updated":"Opened");
}

# Update the target/mgr version in the remote system's managers table, if it's not current.
# Update the local (target/mgr) systems table row for this remote source, setting is_active=true,
# and updating the check_timestamp. If the remote system has been upgraded to a new version, also
# update that column in the systems table row. Close any open alert if the system was previously down.
function updateIsActiveAndRmtMgr($localDbConn, $remoteDbConn, $tgt_system_id_of_src, $mgr_host, $mgr_vers, $src_vers, $remote_name)
{
  global $log;
  global $started;
  global $debug;

  if ($debug) {
	print "=== updateIsActiveAndRmtMgr: sysID=$tgt_system_id_of_src, mgr_host=$mgr_host, mgr_vers=$mgr_vers\n";
	print "    src_vers=$src_vers, remote_name=$remote_name\n";
  }

  # set our local version in the remote system if it lags behind
  $query = "SELECT version FROM bp.managers WHERE LOWER(hostname) = LOWER('$mgr_host')";
  if ($debug) print "Query: $query\n";
  $retval = pg_query($remoteDbConn, $query);
  if ($retval !== false && pg_num_rows($retval) > 0) {
    # update our version string in the DPU's managers table.
    if ($mgr_vers != pg_fetch_result($retval, 0, 0)) {
      $query = "UPDATE bp.managers SET version = '$mgr_vers' WHERE LOWER(hostname) = LOWER('$mgr_host')";
      $retval = pg_query($remoteDbConn, $query);
      if ($retval === false) {
        fprintf($log, "Updating bp.managers on remote system $remote_name failed\n");
      }
	  else {
		fprintf($log, "Updated bp.managers on remote system $remote_name to $mgr_vers for $mgr_host.\n");
	  }
    }
  }

  # update local system is_active and check_timestamp 
  $query = "UPDATE bp.systems SET is_active = true, check_timestamp = $started";

  # see if the remote system's version matches what is in the target/mgr DB.
  # if not, add it to the query to update its systems table row.
  # note that this query is running on the remote system...

  $vers_query = "SELECT version FROM bp.systems WHERE is_local_system = true";
  $retval = pg_query($remoteDbConn, $vers_query);
  if ($retval != false && pg_num_rows($retval) > 0) {
		$remote_vers = pg_fetch_result($retval, 0, 0);
    if ($src_vers != $remote_vers) {
      $query .= ", version = '$remote_vers'";
	  }
  }
  pg_free_result($retval);

  # finish constructing the local query
  $query .= " WHERE system_id = $tgt_system_id_of_src";
  if ($debug) print "Query: $query\n";

  $res = pg_query($localDbConn, $query);
  if ($res == false) {
    fprintf($log, "Updating bp.systems locally for active system $remote_name failed\n");
	if ($debug) print "Failed to update bp.systems locally for active system $remote_name\n";
    return;
  }
  pg_free_result($res);

  # If there is an open alert because the system was previously down,
  # close it and create another notification to say it's now up.

  $existing_alert = haveOpenAlert($localDbConn, 'DPU', $remote_name, 14);

  # only close/raise alert if we're switching from down to up
  if ($existing_alert !== false) {
    $str = createAlertMsg($existing_alert);

    # notify_id 13: Resolve/close alerts for DPU source + target
    bp_send_notification(13, $remote_name);

    # notify_id 15: "%s: DPU database is now responding. %s"
    bp_send_notification(15, $remote_name, $remote_name, "(Down: $str)");

    fprintf($log, "Closed the open alert for $remote_name DB connectivity.\n");
  }
  else {
    if ($debug) print "There is no open alert for $remote_name DB connectivity.\n";
  }
}


function doRun()
{
  global $child_pids;
  global $localDbConn;
  global $loc_conn_str;
  global $bpbin;
  global $log;
  global $master_ini;
  global $dfl_pull_delay;
  global $debug;
  global $started;
  global $local_version;

  # Update the Pid Table
  addOurProcessToPidTable();

  # some local info
  $local_host = trim(`$bpbin/bputil -L`);

  # do local collections, returning updated version if applicable
  doLocalCollection($localDbConn);

  # get managed systems, could be 0
  $systems = getManagedSystemsList();

  # Close the local connection before forking as child processes inherit the connection and closes it when it exits.
  if (isset($systems) && count($systems) > 0) {
    pg_close($localDbConn);
  	fprintf($log, "Version of local system (target/mgr) is %s.\n", $local_version);

    # get delay pull time from master.ini
    $cmd = "$bpbin/bputil -g  \"SyncSummary\" \"PullDelay\" \"$dfl_pull_delay\" $master_ini";
    $pullDelay = trim(`$cmd`);
    if ( $pullDelay == "" ) {
      fprintf($log, "Failed to retrieve Sync Summary Pull Delay setting from $master_ini.");
      $pullDelay = $dfl_pull_delay;
    }
    fprintf($log, "%s: Delaying the pull request for %d seconds.", date('Y-m-d H:i:s'), $pullDelay);
    sleep(abs($pullDelay));
    $started = time();
    fprintf($log, "Delay over at %s.\n", date('Y-m-d H:i:s'));
  }

  foreach ($systems as $key => $value) {
    $tgt_system_id_of_src = $value['system_id'];
    $host = $value['host'];
    $name = $value['name']; # This is what the alerts need
    # This is the version of the source in the target/mgr systems table.
    $src_version = $value['version'];

	if ($debug) print "Forking child for system_id $tgt_system_id_of_src, $name, version $src_version\n";

    $child_pid = pcntl_fork();

    if ($child_pid == -1) {
      # The fork failed.
      fprintf($log, "  Fork failed for system %s.\n", $host);
      continue;
    }
    else if ($child_pid == 0) {
      # We are the child, do the pull and active state
      #fclose($log);

      # get a local connection
      $localDbConn = pg_connect($loc_conn_str);
      if ($localDbConn === false) {
        fprinf($log, "Could not connect to the database.\n");
        exit(-1);
      }

      $rem_conn_str = "port=5432 dbname=bpdb host=$host user=postgres connect_timeout=30";
      $remoteDbConn = pg_connect($rem_conn_str);

      if ($remoteDbConn === false) {
        fprintf($log, "Could not connect to the database on host $host.\n");
        updateInActive($localDbConn, $tgt_system_id_of_src, $name);
        pg_close($localDbConn);
        exit(-1);
      }

      $retval = doPull($localDbConn, $remoteDbConn, $tgt_system_id_of_src);
      if ($retval == 0) {
        updateIsActiveAndRmtMgr($localDbConn, $remoteDbConn, $tgt_system_id_of_src, $local_host, $local_version, $src_version, $name);
      }
      pg_close($localDbConn);
      pg_close($remoteDbConn);
      exit(0);
    }
    else {
      # We are the parent, add child_pid to array and continue, we'll monitor all children once all are started
      if ($debug) print "child pid is $child_pid\n";
      $child_pids[$host] = $child_pid;
    }
  }
  # Re-open the local connection if it was closed 
  if (isset($systems) && count($systems) > 0) {
    $localDbConn = pg_connect($loc_conn_str);
  }

  # Catch signals in the parent process only and let the parent kill the children
  # This approach works best to deal with a child process hung on nw issues
  if (isset($child_pid)) {
    installSigHandlers();
  }

  # Parent process, wait for all children to complete (gives the parent the chance to cancel as needed)
  foreach ($child_pids as $key => $pid) {
    if ($debug) print "Waiting on child $key, PID $pid to complete.\n";
    while (pcntl_waitpid($pid, $status, WNOHANG) == 0) {
      sleep(1);
    }
    if ($debug) print "Child $key, PID $pid is complete.\n";
    unset($child_pids[$key]);
  }

  # vacuum the local tables as needed
  vacuumLocalTables($localDbConn);
}

function doLocalCollection($localDbConn)
{
  global $bpbin;
  global $log;
  global $in_progress;
  global $latest;
  global $debug;

  # Capture local items including archive enabled, and if installs are in progress

  # Archive enabled or not 
  $archive = 'Not enabled';
  $ret = bp_get_archive_schedule_list();
  if ($ret === false || $ret === NULL) {
    # log something...
  } else if (count($ret) > 0) {
    $archive = 'Enabled';
  }
  if ($debug) print "ARCHIVE is $archive\n";

  # Installs in progress or not
  # Version status is updated to 1 of 4 values: "update_in_progress", "update_available", "latest",
  # or "unknown". "update_available" is set from populate_alerts.php, once a day. This script checks
  # for active installs. If it determines installs are in progress, it updates the version_status.
  # If it determines installs are not in progress, then it only updates the version_status if it was
  # set to 'update_in_progress' or null.

  # Any yums running, influences the version_status
  $runningYums = array();
  exec("pgrep yum", $runningYums);

  # get the current version status setting
  $query = "SELECT version_status FROM bp.sync_summary where system_id = (SELECT system_id from bp.systems where is_local_system = 't')";
  if ($debug) print "QUERY: $query\n";
  $res = pg_query($localDbConn, $query);
  if ($res == false) {
    fprintf($log, "Failed to query sync_summary table for local collection.\n");
    return 1;
  }

  # Expecting only one
  $version_status = "";
  if (pg_num_rows($res) == 1) {
    $row = pg_fetch_row($res);
    $version_status = $row[0];
  }
  # fix up the strings to match activity in progress
  # if yum is running, update the version status
  if (isset($runningYums) && count($runningYums) > 0) {
    $version_status = $in_progress;
  }
  else {
    # Yum is not running, if version_status was "update_in_progress" or "", set version_status to "latest".
    # When populate alerts runs it may update version status to "update available".
    if ($version_status == $in_progress || $version_status == "") {
      $version_status = $latest;
    }
  }
  pg_free_result($res);

  # Populate the 'registered_assets' column.  This is the number of direct-attached
  # instances that can be backed up. This query excludes the 3 instances that belong
  # to the appliance itself (file-level, Archive, & System Metadata), plus any of
  # the replicated instances on a target. Also exclude the file-level instance for
  # vCenter-RRC. Only count "current" instances.

  $NT_SERVER = 1;  # denotes system client in nodes.options

  $query = "SELECT COUNT(*) FROM bp.nodes JOIN bp.application_instances USING(node_no) ";
  $query .= "WHERE options != $NT_SERVER AND system_id IS NULL AND current=true ";
  $query .= "AND NOT(node_name='vCenter-RRC' AND app_id=1)";
  if ($debug) print "QUERY: $query\n";

  $res = pg_query($localDbConn, $query);
  if ($res == false || pg_num_rows($res) == 0) {
    fprintf($log, "Failed to count registered assets for local collection.\n");
    return 1;
  }
  # the registered asset count for the system
  $ra = pg_fetch_result($res, 0, 0);
  pg_free_result($res);

  # Do the SQL Update
  $local_system_id = bp_get_local_system_id();
  /* Try Update */
  $update = "UPDATE bp.sync_summary SET registered_assets = $ra, archive='$archive', version_status = '$version_status' WHERE system_id = $local_system_id";
  if ($debug) print "QUERY: $update\n";
  $retval = pg_query($localDbConn, $update);
  if (!$retval || pg_affected_rows($retval) == 0) {
    /* Try Insert */
    $insert = "INSERT INTO bp.sync_summary (system_id, registered_assets, archive, version_status) VALUES ($local_system_id, $ra, '$archive', '$version_status')";
    if ($debug) print "QUERY: $insert\n";
    $retval = pg_query($localDbConn, $insert);
  }

  return 0;
}

function doPull($localDbConn, $remoteDbConn, $tgt_system_id_of_src)
{
  global $log;
  global $debug;

  # get summary sync table info from remote system
  $query = "SELECT system_id, total_mb_size, total_mb_free, registered_assets, archive, version_status FROM bp.sync_summary where system_id = (SELECT system_id from bp.systems where is_local_system ='t')";
  if ($debug) print "QUERY: $query\n";
  $res = pg_query($remoteDbConn, $query);
  if ($res == false) {
    fprintf($log, "Failed to query sync_summary table for remote system, $tgt_system_id_of_src.\n");
    return 0; # Return 0, the connection was set by doPull() caller. This failure could be the remote system version doesn't support sync_summary.
  }

  # Expecting only one
  if (pg_num_rows($res) == 1) {
    $row = pg_fetch_row($res);
    if ($debug) print "doPull(), Remote DB from localsysid: $tgt_system_id_of_src, system_id:$row[0], total_mb_size:$row[1], total_mb_free:$row[2], registered_assets:$row[3], archive:$row[4], version_status:$row[5]\n";
    # Update or Insert record using the local (target's) system_id that represents the managed source
    /* Try Update */
    $update = "UPDATE bp.sync_summary SET total_mb_size=$row[1], total_mb_free=$row[2], registered_assets=$row[3], archive='$row[4]', version_status='$row[5]' WHERE system_id = $tgt_system_id_of_src";
    if ($debug) print "UPDATE: $update\n";
    $retval = pg_query($localDbConn, $update);
    if (!$retval || pg_affected_rows($retval) == 0) {
      /* Try Insert */
      $insert = "INSERT INTO bp.sync_summary (system_id, total_mb_size,total_mb_free,registered_assets,archive,version_status) VALUES ($tgt_system_id_of_src, $row[1],$row[2],$row[3],'$row[4]','$row[5]')";
      if ($debug) print "INSERT: $insert\n";
      $retval = pg_query($localDbConn, $insert);
    }
  }
  else {
    # log this error, why more than one record?
    fprintf($log, "Expected only 1 record from remote system id of $tgt_system_id_of_src\n");
    while ($row = pg_fetch_row($res)) {
      fprintf($log, "doPull(), Remote DB from localsysid: $system_id, system_id:$row[0], total_mb_size:$row[1], total_mb_free:$row[2], registered_assets:$row[3], archive:$row[4], version_status:$row[5]\n");
    }
  }
  pg_free_result($res);

  return 0;
}

function installSigHandlers()
{
  # Catch signals
  pcntl_signal(SIGHUP, "sigHandler");
  pcntl_signal(SIGINT, "sigHandler");
  pcntl_signal(SIGQUIT, "sigHandler");
  pcntl_signal(SIGTERM, "sigHandler");
}

function sigHandler($sig)
{
  global $child_pids;
  global $log;

  #echo "Sig handler $sig called\n";
  foreach ($child_pids as $key => $pid) {
    fprintf($log, "Sending SIGTERM to child %d\n", $child_pid);
    echo "Sending SIGTERM to child $pid\n";
    posix_kill($pid, SIGTERM);
  }
  $msg = "Caught signal ".$sig;
  msg_and_exit($msg, $sig);
}

function amIRunning(&$parentPid)
{
  global $program_name;
  global $localDbConn;
  global $pid;
  global $debug;

  # Validate a process is running by both a database check and a linux process check just 
  # in case something bad happened and it left things in an inconsistent state.
  $pidFoundInTable = 0;
  $pidProcessFound = 0;

  # Check the database for our program
  $query = "SELECT pid FROM bp.pids WHERE filename = '$program_name'";
  if ($debug) print "QUERY: $query\n";
  $res = pg_query($localDbConn, $query);
  if ($res == false) {
    fprintf($log, "ERROR: Failed to query PIDS table for $program_name pid.\n");
  }
  else if (pg_num_rows($res) > 0) {
    $row = pg_fetch_row($res);
    $parentPid = $row[0];
    if ($debug) print "Pid $parentPid found in bp.pids table\n";
    $pidFoundInTable = 1;
  }

  # Check linux processes
  $runningPids = array();
  exec("pgrep $program_name", $runningPids);
  if (isset($runningPids) && (($runningPids[0] != $pid) || (count($runningPids) > 1))) {
    #var_dump($runningPids);
    if ($debug) print "Pid found in linux process list, $runningPids\n";
    $pidProcessFound = 1;
    #if (!isset($parentPid)) { $parentPid = $runningPids;}
  }

  # Both found, therefore running
  if ($pidFoundInTable && $pidProcessFound) {
    return true;
  }

  # Neither found, not running
  if (!$pidFoundInTable && !$pidProcessFound) {
    return false;
  }

  # Mixture, clean up stale Pid entries
  if ($pidFoundInTable && !$pidProcessFound) {
    rmOurProgramFromPidTable();
    return false;
  }
  else {
    # a process is running
    return true;
  }
}

function msg_and_exit($msg, $ret_code)
{
  global $log;
  global $pid;
  global $localDbConn;
  global $debug;

  # Print message and exit with return code.

  if (isset($pid)) {
    $res = pg_query($localDbConn, "DELETE FROM bp.pids WHERE pid=".$pid);
    if ($res == false) {
      $db_err = pg_last_error($localDbConn);
      echo "Failed to remove our process from Pid Table: ".$db_err;
      unset($pid);
    }
  }

  if ($ret_code != 0) {
    fprintf($log, "ERROR: %s\n", $msg);
  }
  else {
    fprintf($log, "%s\n", $msg);
  }
  fprintf($log, "Summary sync collection and pull ended at %s\n", date('Y-m-d H:i:s'));
  fclose($log);
  pg_close($localDbConn);
  exit($ret_code);
}

function rmOurProgramFromPidTable()
{
  global $pid;
  global $localDbConn;
  global $program_name;
  global $debug;

  if (!isset($pid)) {
    return;
  }

  # Delete the record from the devices table.
  $query = "DELETE FROM bp.pids WHERE filename = '$program_name'";
  if ($debug) print "QUERY: $query\n";
  $res = pg_query($localDbConn, $query);
  if ($res == false) {
    $db_err = pg_last_error($localDbConn);
    $msg = "Failed to remove our process from Pid Table: ".$db_err;
    msg_and_exit($msg, 1);
    unset($pid);
  }
}

function addOurProcessToPidTable()
{
  global $program_name;
  global $pid;
  global $localDbConn;
  global $debug;

  $uinfo   = posix_getpwuid(posix_getuid());
  $user    = $uinfo["name"];
  $host    =  php_uname('n');
  $comment = "$program_name is active";

  $ins = "INSERT INTO bp.pids (pid, filename, operator_name, comment, ";
  $ins .= "misc1, time_stamp) VALUES (".$pid.",'$program_name','";
  $ins .= $user."@".$host."','".$comment."',null,".time().")";
  if ($debug) print "QUERY: $ins\n";
  $res = pg_query($localDbConn, $ins);
  if ($res == false) {
    $msg = "Failed to register program in PIDS table.";
    unset($pid);
    msg_and_exit($msg, 1);
  }
  else {
    pg_free_result($res);
  }
}

function getManagedSystemsList()
{
  global $localDbConn;
  global $debug;
  global $local_version;

  # get all systems except the local system
  $systems = array();

  if (!bp_local_system_is_mgr()) {
    return $systems;
  }
  $local_system_id = bp_get_local_system_id();

  # Not using the bp_get_system_list API because it does not return host values.
  $query = "SELECT system_id, name, host, version, is_active FROM bp.systems WHERE role <> 'Non-managed Replication Source'";
  if ($debug) print "QUERY: $query\n";
  $res = pg_query($localDbConn, $query);
  if ($res == false) {
    $msg="Failed to query systems table.\n";
    msg_and_exit($msg, 1);
  }

  # walk the list and build a result array, weeding out the local system
  while ($row = pg_fetch_row($res)) {
    if ($row[0] != $local_system_id) {
      $arrayElement = array();
      $arrayElement['system_id'] = $row[0];
      $arrayElement['name']      = $row[1];
      $arrayElement['host']      = $row[2];
      $arrayElement['version']   = $row[3];
      $arrayElement['is_active'] = $row[4];
      $systems[] = $arrayElement;
    }
	else {
      # save version of local system (target/mgr)
	  $local_version = $row[3];
	}
  }
  pg_free_result($res);

  return $systems;
}

function getSyncSummaryFrequency()
{
  global $log;
  global $bpbin;
  global $master_ini;
  global $def_frequency;

  # get sync time from master.ini
  $cmd = "$bpbin/bputil -g  \"SyncSummary\" \"Frequency\" \"$def_frequency\" $master_ini";
  $syncTime = trim(`$cmd`);

  if ( $syncTime == "" ) {
    fprintf($log, "Failed to retrieve Sync Summary Time setting from $master_ini.");
  }

  # validate values
  if ( ($syncTime != 15) && ($syncTime != 20) && ($syncTime != 30) && ($syncTime != 60)) {
    fprintf($log, "syncTime (in: $syncTime) supported values are 15, 20, 30, and 60.\n");
    $syncTime = $def_frequency;
  }

  return $syncTime;
}

function getCronSyncSummaryFrequency()
{
  global $log;
  global $crontab_bin;
  global $program_name;

  # get sync time from crontab
  $syncTime = trim(`$crontab_bin -l | grep '$program_name' | cut -d' ' -f 1 | cut -d'/' -f 2`);

  if ( $syncTime == "" ) {
    fprintf($log, "Failed to retrieve Sync Summary Time from crontab.");
  }

  return $syncTime;
}

function updateCrontab($syncTime)
{
  global $log;
  global $bpbin;
  global $crontab_bin;
  global $program_name;

  $mypid   = getmypid();
  $crontmp = "/tmp/crontmp.$mypid";

  # Get any existing crontab entry.
  $cronEntry = trim(`$crontab_bin -l | grep '$program_name'`);

  if ($cronEntry == "") {
    # no entry, get list of existing cron entries
    `$crontab_bin -l > $crontmp`;

    # create and append the new entry
    $entry="*/$syncTime * * * * $bpbin/$program_name.php -r \n";
    if (file_put_contents ( $crontmp , $entry , FILE_APPEND) === FALSE) {
      fprintf($log, "Unable to append to tmp cron file, $crontmp\n");
      # leave tmp crontab out there for debugging `rm $crontmp`;
      return 1;
    }
  }
  else {
    # update existing, something like:
    # /usr/bin/crontab -l | sed "s/.*syncSummary.*/*\/15 * * * * \/usr\/bp\/bin\/syncSummary.php -r/"

    # Escape the slashes for sed operation
    $bpbinEscaped = addcslashes("$bpbin/$program_name.php -r", '/');

    # Create new entry with escaped minute entry
    $newEntry = "*\/$syncTime * * * * $bpbinEscaped";

    # build and run the cmd to read existing cron entries, replace ours with the updated entry
    $cmd = "$crontab_bin -l | sed \"s/.*$program_name.*/$newEntry/\"";
    `$cmd > $crontmp`;
  }
  
  # update and cleanup
  `$crontab_bin $crontmp`;
  `rm $crontmp`;
  fprintf($log, "crontab updated with $entry");
  return 0;
}

function setupLogging()
{
  global $program_name;
  global $log;
  global $log_count;

  # turn off php errors while we rename files that may not exist
  error_reporting(0);

  $logname = $program_name;
  $i = $log_count;
  while ($i >= 1) {
    $m = $i + 1;
    rename("/usr/bp/logs.dir/$logname.log.$i", "/usr/bp/logs.dir/$logname.log.$m");
    $i--;
  }
  rename("/usr/bp/logs.dir/$logname.log", "/usr/bp/logs.dir/$logname.log.1");

  # set basic php reporting
  error_reporting(E_ERROR | E_WARNING | E_PARSE);

  $log = fopen("/usr/bp/logs.dir/$logname.log", "w");
  if ($log == false) {
    print "Could not open log file for writing.\n";
    exit(1);
  }

  $msg = "### $program_name started on ".date('Y-m-d H:i:s');
  fprintf($log, "%s\n", $msg);
}

function vacuumLocalTables($localDbConn)
{
  # time to vacuum?
  if (timeToVacuum() == true) {
    $query = "VACUUM ANALYZE bp.sync_summary";
    if ($debug) print "QUERY: $query\n";
    $res = pg_query($localDbConn, $query);
    if ($res == false) {
      fprintf($log, "Failed to vacuum sync_summary table for local system.\n");
    }
  }
}

function timeToVacuum()
{
  global $prog_started;
  global $log;
  global $bpbin;
  global $master_ini;
  global $vacuum_day;
  global $dfl_vac_time;
  global $debug;
 
  # only vacuum once a week, e.g. Sunday, 4AM
  if (date("w",$prog_started) != $vacuum_day) {
    #return false;
  }

  # get vacuumTime from master.ini
  $cmd = "$bpbin/bputil -g  \"SyncSummary\" \"VacuumTime\" \"$dfl_vac_time\" $master_ini";
  $vacuumTime = trim(`$cmd`);

  if ( $vacuumTime == "" ) {
    fprintf($log, "Failed to retrieve Sync Summary Vacuum Time setting from $master_ini.");
    $vacuumTime = $dfl_vac_time;
  }

  # convert values to timestamps
  $vacuumTimestamp = strtotime($vacuumTime);

  # advanced the vacuum time by the frequency to see if we still fit in the slot to vacuum
  $syncSummaryFreq = getSyncSummaryFrequency();
  $stAdvanced = strtotime("+$syncSummaryFreq minutes", $prog_started);

  # if the advanced vacuum time is greater then the started time of this task, then it is time to vacuum.
  # e.g. vacuum time 4am, task start time 3:45 am, frequency 15 mins, vacuum = false
  # e.g. vacuum time 4am, task start time 4:00 am, frequency 15 mins, vacuum = true
  # e.g. vacuum time 4am, task start time 4:15 am, frequency 15 mins, vacuum = false
  if ( ($vacuumTimestamp >= $prog_started) && ($vacuumTimestamp < $stAdvanced) ) {
    return true;
  }

  return false;
}

function UsageAndExit()
{
  global $program_name;

  echo "Usage: $program_name <dh> (c | l | r | s | v)\n";
  echo "c, cancel any active collection tasks\n";
  echo "d, enable debugging\n";
  echo "h, print this message and exit\n";
  echo "l, do local collection only\n";
  echo "r, start the collection and pull operations\n";
  echo "s, return status information including activity and the frequency\n";
  echo "v, start a vacuum on the local sync system table\n";

  exit(0);
}

#####################################################################
# Main program starts here
# Parse command line

$opt = 0;
$options = getopt("cdhlrsv");
foreach (array_keys($options) as $options) switch ($options) {
  case 'c':
    $cancel = true;
    $opt++;
  break;
  case 'd':
    $debug = true;
  break;
  case 'h':
    UsageAndExit();
  break;
  case 'l':
    $local = true;
    $opt++;
  break;
  case 'r':
    $runNow = true;
    $opt++;
  break;
  case 's':
    $status = true;
    $opt++;
  break;
  case 'v':
    $vacuum = true;
    $opt++;
  break;
  default:
    UsageAndExit();
}

# Must have 1 option specified
if ($opt != 1) {
  UsageAndExit();
}

setupLogging();

# need bypass_cookie() for bp calls, e.g. bp_get_local_system_id()
bp_bypass_cookie(3);

# Catch signals in the doRun() to deal with fork inheritance issues

# Get a local db connection, used by all the options
$localDbConn = pg_connect($loc_conn_str);
if ($localDbConn === false) {
  fprintf($log, "Could not connect to the database.\n");
  exit(1);
}

# determine if we are running, valid for status option, termination for others.
$parentPid=-1;
$running = amIRunning($parentPid);

# check for status task
if ($status === true) {
  $syncFreq = getSyncSummaryFrequency();
  $runTF = ($running ? 'true' : 'false');
  echo "  Running: $runTF\n";
  echo "Frequency: $syncFreq mins\n";
  exit(0);
}

# check for cancel task
if ($cancel === true) {
  if ($running === false) {
    echo "Tasks are not currently running\n";
  }
  else {
    # if parent pid was located, stop it, which will also terminate its children
    if (isset($parentPid)) {
      posix_kill($parentPid, SIGTERM);
    }
  }
  exit(0);
}

# options left are local, run, vacuum... only allow if not currently running
if ($running === true) {
  $msg = "### $program_name is already running";
  msg_and_exit($msg, 0);
}

if ($runNow === true) {
  doRun();
}
else if ($local === true) {
  doLocalCollection($localDbConn);
}
else if ($vacuum === true) {
  vacuumLocalTables($localDbConn);
}
else {
  fclose($log);
  pg_close($localDbConn);
  UsageAndExit();
}

# update crontab for the next run if different
$syncFreq = getSyncSummaryFrequency();
$cronTime = getCronSyncSummaryFrequency();
if ($syncFreq != $cronTime) {
  updateCrontab($syncFreq);
}

$msg = "### $program_name completed on ".date('Y-m-d H:i:s');
msg_and_exit($msg, 0);

?>
