-- This script applies modifications to the notification framework.  The
-- revision and status are stored in the notification_mgmt table.  A new
-- revision can involve changes at install time, applied by this script,
-- and/or may involve migration of data in the alerts table, applied by
-- program migrate_alerts.php on the first run of alertman after an rpm
-- upgrade.  The status field with have a value of 'needs migration' if
-- migrate_alerts.php should run.
--
-- There is only one record in the notification_mgmt table, with the
-- following values:
--   revision:     the revision level that is currently installed.
--   upgrade_from: the previous level (an rpm upgrade may apply several
--                 revs); this value is transient and only used if data
--                 migration needs to be performed.  Its value is equal
--                 to the current revision if alertman has checked the
--                 status and finalized the upgrade.  Note that it might be
--                 possible (rare) that multiple upgrades occurred without
--                 an intervening run of alertman.
--   status: string, indicates if alertman should run migration, or if all
--                 changes for the revision are complete.  If migration is
--                 needed, alertman will apply any migrations between the
--                 values of "upgrade_from" and "revision" and then update
--                 the notification_mgmt table to indicate final completion.
--
-- The function is separated into blocks, one for each revision.
-- To add changes for a new revision:
--  1. Increment the value of the new_rev variable in the DECLARE block.
--  2. Add a new block with condition "current_revision < new_rev".
--  3. If the revision requires data migration, set the update_status variable
--     in the block to 'needs migration' (add a case to the migrator program
--     to accomplish the migration).  Do not set the value of update_status
--     to complete!  Only set the value if some data in the alerts table
--     needs migration (or some other dynamically generated data).
--
-- This is the basic structure of the function:
--  DECLARE
--  new_rev INTEGER := 3;     <== change this value below in the code
--
--  (...statements to get current_revision & update_status...)
--	IF (current_revision < 1)
--	THEN
--		SQL statements for rev 1
--	END IF;
--	IF (current_revision < 2)
--	THEN
--		SQL statements for rev 2
--      update_status := 'needs migration';
--	END IF;
--	IF (current_revision < new_rev)
--	THEN
--		SQL statements for new_rev
--	END IF;
--
--	UPDATE notification_mgmt SET revision = new_rev, status = update_status;
--

SET search_path TO bp,public;

CREATE OR REPLACE FUNCTION update_notifications()
RETURNS BOOLEAN AS
$BODY$

DECLARE
	NMrow notification_mgmt%ROWTYPE;
	new_rev INTEGER := 102;
	current_revision INTEGER;
	update_status VARCHAR;
        /* starting postgres 9.1 standard_conforming_strings which mangles \n in notifications. we turn it off
           temporarily for inserting values into the tables used by notification framework: bug # 19527 
           standard_conforming_strings is an "internal" setting for PG8.X and is not accessible. We change it
           only in PG9.X where standard_conforming_strings is on by default.
        */
        sqlConformUserContext BOOLEAN;
        sqlConformString VARCHAR;
        escStringWarning VARCHAR;
BEGIN

    -- bug #19527: save the current default settings
    sqlConformString := (SELECT setting from pg_settings where name='standard_conforming_strings');
    escStringWarning := (SELECT setting from pg_settings where name='escape_string_warning');
    sqlConformUserContext := (SELECT context='user' FROM pg_settings WHERE name='standard_conforming_strings');
    -- RAISE NOTICE 'BEFORE: standard_conforming_strings=% escape_string_warning=%', sqlConformString, escStringWarning;

    -- turn off standard_conforming_strings and warning GUC settings
    IF (sqlConformUserContext)
    THEN
        RAISE NOTICE 'Turning off standard_conforming_strings temporarily to load notifications.sql';
        SET standard_conforming_strings = off;
        SET escape_string_warning = off;
    END IF;



-- There should be only one row, the ORDER BY & LIMIT are just in case...
SELECT INTO NMrow * FROM notification_mgmt ORDER BY revision DESC LIMIT 1 ;

current_revision := NMrow.revision;
update_status := NMrow.status;

IF (current_revision >= new_rev)
THEN
	RETURN TRUE;
END IF;

IF (current_revision < 1)
THEN
--  Inserts for categories table, columns are: category_id, category
	INSERT INTO categories VALUES (0, 'Internal');
	INSERT INTO categories VALUES (1, 'Platform');
	INSERT INTO categories VALUES (2, 'Storage');
	INSERT INTO categories VALUES (3, 'Core');
	INSERT INTO categories VALUES (4, 'Backup');
	INSERT INTO categories VALUES (5, 'Restore');
	INSERT INTO categories VALUES (6, 'Management');
	INSERT INTO categories VALUES (7, 'Archiving');
	INSERT INTO categories VALUES (8, 'Vaulting');

	INSERT INTO trap_types VALUES (1, 'Clients state has changed');
	INSERT INTO trap_types VALUES (2, '3ware state has changed');
	INSERT INTO trap_types VALUES (3, 'PCI state has changed');
	INSERT INTO trap_types VALUES (5, 'Process state has changed');
	INSERT INTO trap_types VALUES (6, 'Disk state has changed');
	INSERT INTO trap_types VALUES (7, 'CEP state has changed');
	INSERT INTO trap_types VALUES (8, 'DPU state has changed');
	INSERT INTO trap_types VALUES (9, 'RAID state has changed');
	INSERT INTO trap_types VALUES (10, 'Backup state has changed');
	INSERT INTO trap_types VALUES (99, 'Test Trap');

--- Initial value for non-migrated alert records
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(0, 0, 'Internal notice', 'Non-migrated alert record',
	0, true, NULL, false, false, false, false, false);

--  Add new column to alerts; alertman will migrate/assign values
	ALTER TABLE alerts ADD COLUMN notification_id INTEGER REFERENCES
		notifications(notification_id) DEFAULT 0;

--- Inserts for notifications table, columns are:
---   notification_id category_id short_description primary_text
---   severity state action alert trap email psa
--- alert_source 3ware
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(1, 0, 'Internal notice',
	'Resolve/Close alerts for 3ware alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(2, 2, '3ware state has changed',
	'3ware %s unit status changed %s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(3, 2, '3ware state has changed',
	'3ware %s drive status changed %s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(4, 2, '3ware state has changed',
	'3ware %s unit status changed %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(5, 2, '3ware state has changed',
	'3ware %s drive status changed %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(6, 2, '3ware state has changed',
	'3ware %s unit status changed %s',
	3, true, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(7, 2, '3ware state has changed',
	'3ware %s drive status changed %s',
	3, true, NULL, true, true, false, false, false);

--- alert_source Clients
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(8, 0, 'Internal notice',
	'Resolve/Close alerts for Clients alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(9, 4, 'Client state has changed',
	'%s: client is no longer listening to connections. %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(10, 4, 'Client state has changed',
	'%s: client is now listening to connections. %s',
	3, true, NULL, true, true, false, false, false);

--- alert_source Disk
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(11, 0, 'Internal notice',
	'Resolve/Close alerts for Disk alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(12, 2, 'Disk space usage warning',
	'Disk space usage threshold exceeded. Disk %s is %s full (%s MB free).',
	2, false, NULL, true, true, false, false, false);

--- alert_source DPU
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(13, 0, 'Internal notice',
	'Resolve/Close alerts for DPU alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(14, 6, 'DPU state has changed',
	'%s: cannot connect to DPU database. %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(15, 6, 'DPU state has changed',
	'%s: DPU database is now responding. %s',
	3, true, NULL, true, true, false, false, false);

--- alert_source PCI
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(16, 0, 'Internal notice',
	'Resolve/Close alerts for PCI alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(17, 1, 'PCI state has changed',
	'PCI device has been disconnected: %s',
	2, true, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(18, 1, 'PCI state has changed',
	'PCI device has been installed: %s',
	3, true, NULL, true, true, false, false, false);

--- alert_source Process
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(19, 0, 'Internal notice',
	'Resolve/Close alerts for Process alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(20, 4, 'License expiration',
	'License: DPU license has expired.',
	1, false, NULL, true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(21, 3, 'CryptoDaemon process state has changed',
	'Process: cryptoDaemon is required but not running.',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(22, 3, 'CryptoDaemon process state has changed',
	'Process: cryptoDaemon is required and running but has no master key.',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(23, 4, 'Licensed capacity exceeded',
	'License Grace Period: The licensed capacity of this DPU has been exceeded.',
	1, false,
	'Please see the system e-mail for urgent upgrade instructions.',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(24, 4, 'Licensed capacity exceeded',
	'License Failure Notification: This DPU cannot perform backups because your data has exceeded the licensed capacity.',
	1, false,
	'Please see the system e-mail for urgent upgrade instructions.',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(25, 6, 'New Rapid Recovery version available',
	'Update: Unitrends Rapid Recovery version %s is available.',
	1, false,
	'To install, go to the Rapid Recovery Console->Configure->Updates.',
	true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(26, 3, 'Tasker process state has changed',
	'Process: Tasker has been stopped.',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(27, 4, 'Licensed capacity warning',
	'License Alert: This DPU is at 70%% of its licensed capacity.',
	2, false,
	'Please see the system e-mail for upgrade instructions.',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(28, 4, 'Licensed capacity warning',
	'License Warning (Yellow Alert): This DPU is at 80%% of its licensed capacity.',
	2, false,
	'Please see the system e-mail for urgent upgrade instructions.',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(29, 4, 'Licensed capacity warning',
	'Urgent License Warning (Red Alert): This DPU is at 90%% of its licensed capacity.  Backup failures are imminent.',
	2, false,
	'Please see the system e-mail for urgent upgrade instructions.',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(30, 4, 'Retention tool warning',
	'Retention: The DPU retention tool was unable to calculate the retention period.',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(31, 4, 'Retention tool warning',
	'Retention: The DPU retention tool has not been initialized.',
	2, false, NULL, true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(32, 4, 'Retention tool warning',
	'Retention: The DPU retention tool initialization grace period has expired.',
	2, false, NULL, true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(33, 1, 'Reboot required',
	'A software update requires the DPU to be rebooted.',
	2, false,
	'Go to the Rapid Recovery Console->Tools->Shutdown.',
	true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(34, 1, 'Driver installation',
	'unitrends-drivers has not been installed.  Will retry in 24 hours.',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(35, 3, 'Migration process state has changed',
	'Migration: long pathname migration %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(36, 4, 'Data Assurance notice',
	'Data Assurance: Your Data Assurance %s.',
	2, true,
	'To renew it, please call the Unitrends Support Center or your Authorized Partner.',
	true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(37, 4, 'Data Assurance notice',
	'Data Assurance: Your Data Assurance expires on %s.',
	3, false,
	'To renew it, please call the Unitrends Support Center or your Authorized Partner.',
	true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(38, 3, 'Tasker process state has changed',
	'Process: Tasker has been started.',
	3, true, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(39, 3, 'CryptoDaemon process state has changed',
	'Process: cryptoDaemon has been started.',
	3, true, NULL, true, true, false, false, false);

--- alert_source RAID
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(40, 0, 'Internal notice',
	'Resolve/Close alerts for RAID alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(41, 2, 'RAID state has changed',
	'RAID drive status changed to offline. %s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(42, 2, 'RAID state has changed',
	'RAID %s: Drive status %s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(43, 2, 'RAID state has changed',
	'RAID %s: Array status %s ',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(44, 2, 'RAID state has changed',
	'RAID %s: Drive status %s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(45, 2, 'RAID state has changed',
	'RAID %s: Array status %s ',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(46, 2, 'RAID state has changed',
	'RAID %s: Drive status %s',
	3, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(47, 2, 'RAID state has changed',
	'RAID %s: Drive status %s',
	3, true , NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(48, 2, 'RAID state has changed',
	'RAID %s: Array status %s ',
	3, true, NULL, true, true, false, false, false);

--- alert_source CEP
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(49, 0, 'Internal notice',
	'Resolve/Close alerts for CEP alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(50, 4, 'CEP state has changed',
	'CEP workspace %s has errors today.',
	1, false,
	'Please check Configure->Exchange->View Error Log.',
	true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(51, 4, 'CEP state has changed',
	'Global Exchange log has errors today.',
	1, false,
	'Please check Configure->Exchange->View Global Error Log.',
	true, true, false, false, false);

--- alert_source Backup
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(52, 0, 'Internal notice',
	'Resolve/Close alerts for Backup alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(53, 4, 'Backup failure',
	'Scheduled backup did not run.  %s',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(54, 4, 'Backup failure',
	'Master backup for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(55, 4, 'Backup failure',
	'Incremental backup for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(56, 4, 'Backup failure',
	'Selective backup for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(57, 4, 'Backup failure',
	'SQL Server backup for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(58, 5, 'Restore failure',
	'Restore for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(59, 4, 'Verification failure',
	'Backup verify for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(60, 4, 'Backup failure',
	'BareMetal backup for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(61, 5, 'Restore failure',
	'BareMetal restore for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(62, 4, 'Backup failure',
	'Backup operation for client %s failed.',
	2, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(63, 6, 'Test Trap',
	'Verify that SNMP configuration is working',
	3, true, NULL, false, true, false, false, false);

--  Inserts for notify_alerts table, columns are: notification_id, source_id
--- alert_source 3ware
	INSERT INTO notify_alerts VALUES(1, 2);
	INSERT INTO notify_alerts VALUES(2, 2);
	INSERT INTO notify_alerts VALUES(3, 2);
	INSERT INTO notify_alerts VALUES(4, 2);
	INSERT INTO notify_alerts VALUES(5, 2);
	INSERT INTO notify_alerts VALUES(6, 2);
	INSERT INTO notify_alerts VALUES(7, 2);
--- alert_source Clients
	INSERT INTO notify_alerts VALUES(8, 1);
	INSERT INTO notify_alerts VALUES(9, 1);
	INSERT INTO notify_alerts VALUES(10, 1);
--- alert_source Disk
	INSERT INTO notify_alerts VALUES(11, 6);
	INSERT INTO notify_alerts VALUES(12, 6);
--- alert_source DPU
	INSERT INTO notify_alerts VALUES(13, 8);
	INSERT INTO notify_alerts VALUES(14, 8);
	INSERT INTO notify_alerts VALUES(15, 8);
--- alert_source PCI
	INSERT INTO notify_alerts VALUES(16, 3);
	INSERT INTO notify_alerts VALUES(17, 3);
	INSERT INTO notify_alerts VALUES(18, 3);
--- alert_source Process
	INSERT INTO notify_alerts VALUES(19, 5);
	INSERT INTO notify_alerts VALUES(20, 5);
	INSERT INTO notify_alerts VALUES(21, 5);
	INSERT INTO notify_alerts VALUES(22, 5);
	INSERT INTO notify_alerts VALUES(23, 5);
	INSERT INTO notify_alerts VALUES(24, 5);
	INSERT INTO notify_alerts VALUES(25, 5);
	INSERT INTO notify_alerts VALUES(26, 5);
	INSERT INTO notify_alerts VALUES(27, 5);
	INSERT INTO notify_alerts VALUES(28, 5);
	INSERT INTO notify_alerts VALUES(29, 5);
	INSERT INTO notify_alerts VALUES(30, 5);
	INSERT INTO notify_alerts VALUES(31, 5);
	INSERT INTO notify_alerts VALUES(32, 5);
	INSERT INTO notify_alerts VALUES(33, 5);
	INSERT INTO notify_alerts VALUES(34, 5);
	INSERT INTO notify_alerts VALUES(35, 5);
	INSERT INTO notify_alerts VALUES(36, 5);
	INSERT INTO notify_alerts VALUES(37, 5);
	INSERT INTO notify_alerts VALUES(38, 5);
	INSERT INTO notify_alerts VALUES(39, 5);
--- alert_source RAID
	INSERT INTO notify_alerts VALUES(40, 9);
	INSERT INTO notify_alerts VALUES(41, 9);
	INSERT INTO notify_alerts VALUES(42, 9);
	INSERT INTO notify_alerts VALUES(43, 9);
	INSERT INTO notify_alerts VALUES(44, 9);
	INSERT INTO notify_alerts VALUES(45, 9);
	INSERT INTO notify_alerts VALUES(46, 9);
	INSERT INTO notify_alerts VALUES(47, 9);
	INSERT INTO notify_alerts VALUES(48, 9);
--- alert_source CEP
	INSERT INTO notify_alerts VALUES(49, 7);
	INSERT INTO notify_alerts VALUES(50, 7);
	INSERT INTO notify_alerts VALUES(51, 7);

--  Inserts for notify_traps table, columns are: notification_id, trap_type, oid
--- alert_source 3ware
	INSERT INTO notify_traps VALUES(2, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(3, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(4, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(5, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(6, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(7, 2, '100.0.2');
--- alert_source Clients
	INSERT INTO notify_traps VALUES(9, 1, '100.0.1');
	INSERT INTO notify_traps VALUES(10, 1, '100.0.1');
--- alert_source Disk
	INSERT INTO notify_traps VALUES(12, 6, '100.0.6');
--- alert_source DPU
	INSERT INTO notify_traps VALUES(14, 8, '100.0.8');
	INSERT INTO notify_traps VALUES(15, 8, '100.0.8');
--- alert_source PCI
	INSERT INTO notify_traps VALUES(17, 3, '100.0.3');
	INSERT INTO notify_traps VALUES(18, 3, '100.0.3');
--- alert_source Process
	INSERT INTO notify_traps VALUES(20, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(21, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(22, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(23, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(24, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(25, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(26, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(27, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(28, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(29, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(30, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(31, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(32, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(33, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(34, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(35, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(36, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(37, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(38, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(39, 5, '100.0.5');
--- alert_source RAID
	INSERT INTO notify_traps VALUES(41, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(42, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(43, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(44, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(45, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(46, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(47, 9, '100.0.9');
	INSERT INTO notify_traps VALUES(48, 9, '100.0.9');
--- alert_source CEP
	INSERT INTO notify_traps VALUES(50, 7, '100.0.7');
	INSERT INTO notify_traps VALUES(51, 7, '100.0.7');
--- alert_source Backup
	INSERT INTO notify_traps VALUES(53, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(54, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(55, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(56, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(57, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(58, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(59, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(60, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(61, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(62, 10, '100.0.10');
--  Test trap (no alert source)
	INSERT INTO notify_traps VALUES(63, 99, '100.0.99');

--  Inserts for notify_emails table, columns are:
--  notification_id, to_section, to_keyword, from_name, subject, body
	INSERT INTO notify_emails VALUES(20, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License has expired.',
	'Your Unitrends DPU license has expired.  Please renew your license.');

	INSERT INTO notify_emails VALUES(23, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'FATAL: License grace period.',
	'License Grace Period: The licensed capacity of this Data Protection Unit has been exceeded. Usage above your current allowance is permitted for a grace period of 7 days (total).  Once this grace period expires, any attempt to perform backups to your Data Protection Unit will automatically be denied by the system.  Your grace period will expire in %s days.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to increase your licensed capacity and restart the process of protecting your data.');

	INSERT INTO notify_emails VALUES(24, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'FATAL: License has expired.',
	'License Failure Notification:  The Total System Content being protected by this Data Protection Unit has now exceeded the licensed capacity (%s GB).  The system is now unable to perform backups until you increase your licensed capacity.  This situation is critical.  Your data is no longer being protected.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to increase your licensed capacity and restart the process of protecting your data.');

	INSERT INTO notify_emails VALUES(27, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'WARNING: License threshold exceeded.',
	'License Alert: The licensed capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 70%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected.  You can upgrade your license by contacting your authorized Unitrends partner or Unitrends representative.');

	INSERT INTO notify_emails VALUES(28, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'WARNING: License threshold exceeded.',
	'License Warning (Yellow Alert): The licensed capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 80%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license.  You can upgrade your license now by contacting your authorized Unitrends partner or Unitrends representative (at 888-374-6124).');

	INSERT INTO notify_emails VALUES(29, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'WARNING: License threshold exceeded.',
	'License Warning (Red Alert): The licensed capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 90%% of the licensed capacity.  You should immediately increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license, and this situation is imminent.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to avoid preventable backup failures.');

	INSERT INTO notify_emails VALUES(31, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'WARNING: License setup grace period.',
	'License Setup Grace Period Notification: The license for this Data Protection Unit has not been initialized.  You must initialize your license within 30 days of upgrade or installation.  Once this grace period expires, any attempt to perform backups to your Data Protection Unit will automatically be denied by the system.  Your grace period will expire in %s days.  Please contact your authorized Unitrends partner or Unitrends Support Center immediately at 888-374-6124 to initialize your license properly and restart the process of protecting your data.');

	INSERT INTO notify_emails VALUES(32, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'FATAL: License setup grace period has expired.',
	'License Setup Grace Period Notification: The license for this Data Protection Unit has not been initialized.  The system is now unable to perform backups until you initialize your license. This situation is critical.  Your data is no longer being protected.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to initialize your license and restart the process of protecting your data.');

	update_status := 'needs migration';

END IF;


IF (current_revision < 2)
THEN
--- Inserts for notifications table, now the columns are:
---   notification_id category_id short_description primary_text
---   severity state action alert trap email log psa
--- Note: category=Storage, trap_type='Disk state has changed'
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(64, 2, 'Deleted backup(s)',
	'Backup(s) for client %s marked for deletion: #%s',
	3, true, NULL, false, true, false, true, false);
	INSERT INTO notify_traps VALUES(64, 6, '100.0.6');

END IF;


IF (current_revision < 3)
THEN
	INSERT INTO trap_types VALUES (11, 'Archiving state has changed');

--- Inserts for notifications table, columns are:
---   notification_id category_id short_description primary_text
---   severity state action alert trap email log psa
--- Note: category='Archiving', trap_type='Archiving state has changed'
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(65, 7, 'DPU Archiving state has changed',
	'Archive job %s is running.',
	1, false, NULL, true, true, false, false, false);
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(66, 7, 'DPU Archiving state has changed',
	'Archive job %s is not running.',
	1, true, NULL, true, true, false, false, false);

	INSERT INTO notify_alerts VALUES(65, 11);
	INSERT INTO notify_alerts VALUES(66, 11);

	INSERT INTO notify_traps VALUES(65, 11, '100.0.11');
	INSERT INTO notify_traps VALUES(66, 11, '100.0.11');
END IF;

IF (current_revision < 4)
THEN
	UPDATE notify_emails
	SET body = 'Your Unitrends Appliance license has expired.  Please renew your license by calling 888-374-6124.'
	WHERE notification_id = 20;
END IF;

IF (current_revision < 5)
THEN
	UPDATE notifications SET severity = 2 WHERE notification_id = 25;
END IF;

IF (current_revision < 6)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(67, 4, 'SQL Server schedule skipped',
	'SQL Server Instance %s on client %s will not perform scheduled backups for database %s because backups of type %s are not supported.',
	1, true, NULL, true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(67, 10);
	INSERT INTO notify_traps VALUES(67, 10, '100.0.10');
END IF;

IF (current_revision < 7)
THEN
	-- Note: category='Archiving', trap_type='Archiving state has changed'
	-- Drive capacity warning
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(68, 7, 'DPU Archiving state has changed',
	'Archive media is at %s%% of capacity.',
	2, true, NULL, true, true, false, false, false);
	-- Drive capacity impending failure
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(69, 7, 'DPU Archiving state has changed',
	'Archive media is at %s%% of capacity.',
	1, true, NULL, true, true, false, false, false);
	-- Archive status email
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(70, 7, 'DPU Archiving state has changed', '%s',
	2, true, NULL, false, false, true, false, false);

	INSERT INTO notify_alerts VALUES(68, 11);
	INSERT INTO notify_alerts VALUES(69, 11);

	INSERT INTO notify_traps VALUES(68, 11, '100.0.11');
	INSERT INTO notify_traps VALUES(69, 11, '100.0.11');

	INSERT INTO notify_emails VALUES(70, 'Unattended Backup Information',
	'MailTo', 'Archive Job Notifications <root>',
	'Archive job completion', '%s');
END IF;

IF (current_revision < 8)
THEN
	INSERT INTO trap_types VALUES(12, 'Version Information');
	INSERT INTO trap_types VALUES(13, 'DPU Open Alerts Status');
	INSERT INTO trap_types VALUES(14, 'Network Status has changed');
	
	-- NOTE: category=Platform, trap_type=Version Information
	-- Version Information (no alert_source)
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(71, 1, 'DPU Version', 'DPU %s',
	3, true, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(72, 1, 'Agent Version',
	'Node Name: %s, Version: %s, Status: %s',
	3, true, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(73, 1, '3ware Information',
	'3ware %s, %s, %s',
	3, true, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(74, 1, 'NIC Collisions',
	'%s: %s',
	1, false, NULL, false, true, false, false, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(75, 1, 'NIC Dropped Packets',
	'%s: %s',
	1, false, NULL, false, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(76, 1, 'NIC Errors',
	'%s: %s',
	1, false, NULL, false, true, false, false, false); 

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(77, 8, 'OpenVPN/Vaulting Status',
	'OpenVPN not enabled while Vaulting is enabled',
	1, false, NULL, false, true, false, false, false);

	INSERT INTO notify_traps VALUES(71, 12, '100.0.12');
	INSERT INTO notify_traps VALUES(72, 12, '100.0.12');
	INSERT INTO notify_traps VALUES(73, 12, '100.0.12');
	INSERT INTO notify_traps VALUES(74, 14, '100.0.14');
	INSERT INTO notify_traps VALUES(75, 14, '100.0.14');
	INSERT INTO notify_traps VALUES(76, 14, '100.0.14'); 
	INSERT INTO notify_traps VALUES(77, 14, '100.0.14');
END IF;

IF (current_revision < 9)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(78, 8,
	'Vaulting operation terminated or reset',
	'%s a vaulting operation for %s''s %s.',
	3, true, NULL, false, true, false, true, false);

	INSERT INTO notify_traps VALUES(78, 5, '100.0.5');
END IF;

IF (current_revision < 10)
THEN

	-- NOTE: category=Core, trap_type="Process state has changed"
	---NOTE: Inserts for notifications table, columns are:
	---   notification_id, category_id, short_description, primary_text
	---   severity, state, action, alert, trap, email, log, psa

	-- alert_source Process
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(79, 3, 'ArchiveDaemon process state has changed',
	'Process: archiveDaemon is not running',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(80, 3, 'ArchiveDaemon process state has changed',
	'Process: archiveDaemon is running',
	3, true, NULL, true, true, false, false, false);

	INSERT INTO notify_alerts VALUES(79, 5);
	INSERT INTO notify_alerts VALUES(80, 5); 
	
	INSERT INTO notify_traps VALUES(79, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(80, 5, '100.0.5');
END IF;

IF (current_revision < 11)
THEN

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(81, 2, 'SMART Information',
	'%s',
	3, true, NULL, false, true, false, false, false);

	INSERT INTO notify_traps VALUES(81, 6, '100.0.6');
END IF;

IF (current_revision < 12)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(82, 3,
	'Migration process state has changed',
	'Update: Processing of existing backups to import file data into the database is %s.',
	3, false, NULL, true, false, false, false, false);
	INSERT INTO notify_alerts VALUES(82, 5);
END IF;

IF (current_revision < 13)
THEN
	--alert_source Disk
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(83, 2, 'External Storage status',
	'External Storage: %s is Online',
	3, true, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(84, 2, 'External Storage status',
	'External Storage: %s is Offline',
	1, false, NULL, true, true, false, false, false); 

	INSERT INTO notify_alerts VALUES(83, 6);
	INSERT INTO notify_alerts VALUES(84, 6);

	INSERT INTO notify_traps VALUES(83, 6, '100.0.6');
	INSERT INTO notify_traps VALUES(84, 6, '100.0.6');
END IF;

IF (current_revision < 14)
THEN
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(85, 0, 'Internal Notice',
	'Resolve/Close alerts for Vault alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(86, 8, 'Vault Capacity Warning',
	'Vault License Alert (Red Alert): Licensed Vault capacity has been met or exceeded',
	1, false, 'Please see system e-mail for urgent upgrade instructions',
	true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(87, 8, 'Vault Capacity Warning',
	'Vault License Warning (Yellow Alert): Vault is at 80%% of its licensed capacity',
	2, false, 'Please see system e-mail for urgent upgrade instructions',
	true, true, true, false, false);

	INSERT INTO notify_alerts VALUES(85, 6);
	INSERT INTO notify_alerts VALUES(86, 6);
	INSERT INTO notify_alerts VALUES(87, 6);

	INSERT INTO notify_traps VALUES(86, 6, '100.0.6');
	INSERT INTO notify_traps VALUES(87, 6, '100.0.6');

	INSERT INTO notify_emails VALUES(86, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'Fatal: Vault License threshold exceeded.',
	'Vault License Warning (Red Alert): The licensed vault capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 100%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your vaulting will disabled in 5 days timeand remain disabled until your license capacity exceeds your data volume.  Please contact your Vault Service Provider for further information.');	

	INSERT INTO notify_emails VALUES(87, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'WARNING: Vault License threshold exceeded.',
	'Vault License Warning (Yellow Alert): The licensed vault capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents %s%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your vaulting will not run correctly if your data volume exceeds your vault license capacity.  Please contact your Vault Service Provider for further information.');	
END IF;

IF (current_revision < 15)
THEN
	-- NOTE: category=Platform, trap_type=BP Agent Version Information
	---NOTE: Inserts for notifications table, columns are:
	---   notification_id, category_id, short_description, primary_text
	---   severity, state, action, alert, trap, email, log, psa

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(88, 1, 'BP Agent Version Information',
	'%s out of %s clients are running an outdated version of BP Agent.',
	2, false, 'Please upgrade your BP Agent.', true, true, false, false, false);

	INSERT INTO notify_alerts VALUES(88, 1); 

	INSERT INTO notify_traps VALUES(88, 1, '100.0.1');
END IF; 
 
IF (current_revision < 16)
THEN
	UPDATE notifications
	  SET primary_text = 'Differential backup for client %s failed.'
	WHERE notification_id = 55;
END IF; 

IF (current_revision < 17)
THEN
	-- 5.0.2 beta wording was different, make the database consistent as of 5.1
	UPDATE notifications
	  SET primary_text = 'Update: Processing of existing backups to import file data into the database is %s.', severity = 3
	WHERE notification_id = 82;
END IF; 

IF (current_revision < 18)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(89, 2, '3ware controller reset Alert',
	'3ware reset AEN:cache synchronization failed, some data lost.',
	1, false, NULL, false, true, false, false, false);

	INSERT INTO notify_traps VALUES(89, 2, '100.0.2');
END IF; 

IF (current_revision < 19)
THEN
	UPDATE notify_emails
	  SET body = 'Vault License Warning (Red Alert): The licensed vault capacity of this Data Protection Unit is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 100%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all of your data is fully protected.  Please contact your Vault Service Provider for further information.'
	WHERE notification_id = 86;

	UPDATE notifications
	  SET primary_text = 'Vault License Warning (Yellow Alert): Vault has crossed 80%% of its licensed capacity'
	WHERE notification_id = 87;
END IF;

IF (current_revision < 20)
THEN
	-- category=Restore, audit log only
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(90, 5, 'A Restore was initiated',
	'%s was started for client %s, %s.',
	3, true, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 21)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(91, 5, 'File-Level Recovery Alert',
	'A VMware File-Level Recovery image existed for over 4 days and was torn down automatically.',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(92, 5, 'File-Level Recovery Alert',
	'A VMware File-Level Recovery image has existed over 1 day.  Within the next 3 days, you must unmount the image from any connected hosts, then tear it down in the RRC',
	2, false, NULL, true, false, false, false, false);

	INSERT INTO notify_alerts VALUES(91, 6);
	INSERT INTO notify_alerts VALUES(92, 6);

	INSERT INTO notify_traps VALUES(91, 6, '100.0.6');
END IF; 

IF (current_revision < 22)
THEN
	-- Overload Alert/Trap category=Core 
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(93, 3, 'Appliance Overloaded',
	'Appliance appears overloaded; delays have been seen %s%% of the time over the past %s.', 
	2, false, 'If this continues, you should consider either purchasing another appliance to accommodate this workload or decreasing the backups on this appliance.',
	true, true, false, false, false);
	-- alert_source Process
	INSERT INTO notify_alerts VALUES(93, 5);
	INSERT INTO notify_traps VALUES(93, 5, '100.0.5');
END IF;

IF (current_revision < 23)
THEN
	-- Backup promotion Alert/Trap category=Backup
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(94, 4, 'Backup Type Promotion',
	'%s was promoted to %s for %s because %s.',
	2, false, NULL, true, true, false, false, false);

	-- alert_source/trap_type Backups
	INSERT INTO notify_alerts VALUES(94, 10);
	INSERT INTO notify_traps VALUES(94, 10, '100.0.10');

	-- We need a notify_alerts record to Resolve/Close Backup alert source
	-- (didn't previously need it because this source only sent traps)
	INSERT INTO notify_alerts VALUES(52, 10);
END IF;

IF (current_revision < 24)
THEN
	-- Space Alert/Trap category=Backup
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(95, 4, 'Growth of Critical Backup Data',
	'The total amount of critical client data is approaching the appliance capacity.',
	2, false, 'Consider either purchasing another appliance to accommodate this critical data, or decreasing the amount of data protected by this appliance.',
	true, true, false, false, false);
	-- alert_source/trap_type Backups
	INSERT INTO notify_alerts VALUES(95, 10);
	INSERT INTO notify_traps VALUES(95, 10, '100.0.10');
END IF;

IF (current_revision < 25)
THEN
	-- category=Platform
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(96, 1, 'vRecovery Call Home',
	'%s has been deployed.',
	3, true, NULL, false, true, false, false, false);

	-- trap_type Version Information
	INSERT INTO notify_traps VALUES(96, 12, '100.0.12');
END IF;

IF (current_revision < 26)
THEN
	UPDATE notifications
	  SET primary_text = 'Appliance appears overloaded; a significant amount of processing delays have been seen over the past %s.'
	WHERE notification_id = 93;
END IF;

IF (current_revision < 27)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(97, 4, 'License Expiration Approaching',
	'License: Appliance license will expire in 30 days.',
	2, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(98, 4, 'License Expiration Approaching',
	'License: Appliance license will expire in 14 days.',
	2, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(99, 4, 'License Expiration Approaching',
	'License: Appliance license will expire in 7 days.',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notify_alerts VALUES(97, 5);
	INSERT INTO notify_alerts VALUES(98, 5);
	INSERT INTO notify_alerts VALUES(99, 5);

	INSERT INTO notify_traps VALUES(97, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(98, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(99, 5, '100.0.5');

	INSERT INTO notify_emails VALUES(97, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'Your Unitrends Appliance license will expire in 30 days. Please renew your license by calling 888-374-6124.');

	INSERT INTO notify_emails VALUES(98, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'Your Unitrends Appliance license will expire in 14 days. Please renew your license by calling 888-374-6124.');

	INSERT INTO notify_emails VALUES(99, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'Your Unitrends Appliance license will expire in 7 days. Please renew your license by calling 888-374-6124.');
END IF;

IF (current_revision < 28)
THEN
	UPDATE notifications
	SET primary_text = 'A VMware File-Level Recovery image has existed for more than 3 days. You must unmount the image from any connected hosts, then tear it down in the RRC.'
	WHERE notification_id = 92;
END IF;


IF (current_revision < 29)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(100, 0, 'Internal notice', 'Resolve/Close alerts for Retention alert source',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(101, 4, 'Retention goal alert', '%s has protection below minimum retention goal of %s days.',
	1, false, NULL, true, true, false, true, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(102, 4, 'Retention limit alert', '%s has protection above maximum retention limit of %s days.',
	1, false, NULL, true, true, false, true, false);

	INSERT INTO notify_alerts VALUES(100, 12);
	INSERT INTO notify_alerts VALUES(101, 12);
	INSERT INTO notify_alerts VALUES(102, 12);
	
	INSERT INTO notify_traps VALUES(101, 10, '100.0.10');
	INSERT INTO notify_traps VALUES(102, 10, '100.0.10');
	
END IF;

IF (current_revision < 30)
THEN
	-- Unresolved alert, trap for failed DR --
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(103, 5, 'Disaster Recovery failure alert', 'Disaster Recovery of %s',
	2, false, NULL, true, true, false, false, false);
	
	-- Resolved alert, trap, email for successful DR -- 
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(104, 5, 'Disaster Recovery success alert', '%s',
	3, true, NULL, true, true, true, false, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(105, 0, 'Internal notice', 'Resolve/Close alerts for Disaster Recovery',
	0, true, NULL, true, false, false, false, false);
	
	INSERT INTO notify_alerts VALUES(103, 13);
	INSERT INTO notify_alerts VALUES(104, 13);
	INSERT INTO notify_alerts VALUES(105, 13);

	INSERT INTO notify_traps VALUES(103, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(104, 5, '100.0.5');
	
	INSERT INTO notify_emails VALUES(104, 'Unattended Backup Information',
	'MailTo', 'Disaster Recovery Notifications <root>',
	'Disaster Recovery complete', '%s %s');
	
END IF;

IF (current_revision < 31)
THEN
	-- Category=Backup, alert, trap, email
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(106, 4, 'Client volumes have changed',
	'Volumes on %s have changed from %s to %s.', 2, false,
	'File-level schedules for this client should be updated.',
	true, true, true, false, false);

	-- Alert source Clients
	INSERT INTO notify_alerts VALUES(106, 1);
	INSERT INTO notify_traps VALUES(106, 1, '100.0.1');
	INSERT INTO notify_emails VALUES(106, 'Unattended Backup Information',
	'MailTo', 'Schedule Notifications <root>',
	'Client volumes have changed', 'Volumes on the the client %s have changed.  The previous list of volumes was:\n %s\nThe current list is:\n %s\nFile-level schedules that include this client should be re-saved or modified to incorporate these changes.\n\nIf new volumes were added and should be included in backups, re-save the schedule(s) to automatically add the new volume(s).  If new volumes should not be backed up, add them to an exclusion list.\n\nIf volumes were permanently removed, re-save the schedule to automatically eliminate them from the backup profile.\n\nFile-level schedules that include this client:\n%s\n');

	-- Close alert (no trap or email sent)
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(107, 4,
	'Resolve notice of client volume change',
	'Warning of change in volumes on %s is resolved: %s.', 3, true, NULL,
	true, false, false, false, false);
	INSERT INTO notify_alerts VALUES(107, 1);
END IF;

IF (current_revision < 32)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(108, 2, 'Storage Migration alert', '%s mount point has been migrated to %s.',
	2, true, 'Please correct all selection list entries effected by the migrated path.',
	true, true, false, false, false);

	INSERT INTO notify_alerts VALUES(108, 6);
	INSERT INTO notify_traps VALUES(108, 6, '100.0.6');
END IF;

IF (current_revision < 33)
THEN
	-- MaxBackups Space Alert/Trap/Email category=Backup
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(109, 4,
	'Growth of Critical Backup Data',
	'The total amount of critical client data (%s) has exceeded the maximum backup capacity (%s) of %s, and therefore operations such as deduplication have been turned off.',
	1, false, 'You need to purchase another appliance to accommodate this critical data, or reduce the amount of data protected by this appliance.',
	true, true, true, false, false);
	-- alert_source/trap_type Backups
	INSERT INTO notify_alerts VALUES(109, 10);
	INSERT INTO notify_traps VALUES(109, 10, '100.0.10');
	INSERT INTO notify_emails VALUES(109, 'Unattended Backup Information',
	'MailTo', 'Storage Notifications <root>',
	'Growth of Critical Backup Data',
	'The total amount of critical client data (%s) has exceeded the maximum backup capacity (%s) of %s, and therefore operations such as deduplication have been turned off.  You need to purchase another appliance to accommodate this critical data, or reduce the amount of data protected by this appliance.\n\nPlease refer to the Capacity Report for details about the amount of maximum backup capacity consumed by individual clients.');

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(110, 4,
	'Resolve notice about Maximum Backup Capacity exceeded',
	'The total amount of critical client data (%s) is now less than the maximum backup capacity (%s) of %s, and deduplication has been re-enabled.',
	3, true, NULL, true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(110, 10);
	INSERT INTO notify_traps VALUES(110, 10, '100.0.10');

END IF;

IF (current_revision < 34)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(111, 2, 'Vaulted Clients Storage Usage',
	'Vault client %s is using %s GB of vaulting storage space.',
	3, true, NULL, false, true, false, false, false);

	INSERT INTO notify_traps VALUES(111, 6, '100.0.6');
END IF;

IF (current_revision < 35)
THEN
    -- Virtual client has been live >14 days, category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(112, 3, 'Virtual Client Notice',
	'You have been running client %s as a virtualized server on %s for 14 or more days.',
	1, false, 'Please back up this client and restore to a replacement server as soon as possible.',
	true, true, false, false, false);
	-- Clients alert_source, trap_type
	INSERT INTO notify_alerts VALUES(112, 1);
	-- This trap OID is wrong; fixed in rev 42 (should be Clients, 100.0.1)
	INSERT INTO notify_traps VALUES(112, 1, '100.0.6');
END IF;

IF (current_revision < 36)
THEN
    -- Virtual client has been invalidated, category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(113, 3, 'Virtual Client Notice',
	'The virtual client for %s has been invalidated because %s.',
	1, false, 'Please delete the virtual client and start over.',
	true, true, false, false, false);
	-- Clients alert_source, trap_type
	INSERT INTO notify_alerts VALUES(113, 1);
	-- This trap OID is wrong; fixed in rev 42 (should be Clients, 100.0.1)
	INSERT INTO notify_traps VALUES(113, 1, '100.0.6');
END IF;

IF (current_revision < 37)
THEN
	-- VMware Instant Recovery
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(114, 5, 'Instant Recovery Alert',
	'A VMware Instant Recovery session has existed for more than 3 days.  Please return to the Instant Recovery interface Job Status in the RRC and tear down the session.',
	2, false, NULL, true, true, true, false, false);

	INSERT INTO notify_alerts VALUES(114, 6);

	INSERT INTO notify_emails VALUES(114, 'Unattended Backup Information',
	'MailTo', 'Restore Notifications <root>', 'WARNING: VMware Instant Recovery session still active',
	'A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended.  Please return to the RRC and use the "Instant Recovery Job Status" tool to tear down the session.');

	INSERT INTO notify_traps VALUES(114, 1, '100.0.6');
END IF;

IF (current_revision < 38)
THEN
	-- Virtual client halted for lack of sufficient reservation space
	-- Category=Storage
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(115, 2, 'Virtual Client Halted',
	'The virtual client for %s has halted operations due to disk space shortage.',
	1, false,
	' Please reallocate more space to virtual failover or delete a virtual client and try again.',
	true, true, true, false, false);
	-- Disk alert_source, trap_type
	INSERT INTO notify_alerts VALUES(115, 6);
	INSERT INTO notify_traps VALUES(115, 6, '100.0.6');
	INSERT INTO notify_emails VALUES(115, 'Unattended Backup Information', 
	'MailTo', 'Storage Notifications <root>', 'Virtual Client Halted',
	'The virtual client for %s has halted operations due to disk space shortage.  Please reallocate more space to virtual failover or delete a virtual client and try again.');

	-- Close alert, send email (no trap sent)
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(116, 2,
	'Resolve Notice of Halted Virtual Client', 'The virtual client for %s is no longer halted due to insufficient space allocation.',
	3, true, NULL, true, false, true, false, false);
	INSERT INTO notify_alerts VALUES(116, 6);
	INSERT INTO notify_emails VALUES(116, 'Unattended Backup Information', 
	'MailTo', 'Storage Notifications <root>',
	'Resolution of Halted Virtual Client',
	'The virtual client for %s is no longer halted due to insufficient space allocation.');
END IF;

IF (current_revision < 39)
THEN
    	-- Virtual failover capacity reached alert limit, category=Storage
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(117, 2, 'Virtual Failover Notice',
	'Usage of the virtual failover area has exceeded %s%%, currently %s%% in use',
	2, false, NULL,	true, true, false, false, false);
	
	INSERT INTO notify_alerts VALUES(117, 6);
	INSERT INTO notify_traps VALUES(117, 6, '100.0.6');
END IF;

IF (current_revision < 40)
THEN
	-- category=Storage, audit log only
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(118, 2, 'Storage allocation was changed',
	'Storage allocation for %s has changed from %.02f GB to %.02f GB.',
	3, true, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 41)
THEN
    -- Virtual client verification failed, email only, category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(119, 3, 'Virtual Client Notice',
	'Recovery verification for %s failed because %s.',
	2, true, NULL, false, false, true, false, false);
	INSERT INTO notify_emails VALUES(119, 'Unattended Backup Information', 
	'MailTo', 'Instant Recovery Verification <root>',
	'Recovery Verification Failed',
	'Recovery verification of the virtual client for %s failed because %s.');
END IF;

IF (current_revision < 42)
THEN
    -- Virtual client has been deleted, category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(120, 3, 'Virtual Client Notice',
	'The virtual client for %s has been deleted.', 2, true, NULL,
	true, true, false, false, false);
	-- Clients alert_source, trap_type
	INSERT INTO notify_alerts VALUES(120, 1);
	INSERT INTO notify_traps VALUES(120, 1, '100.0.1');

	-- Fix trap OID for notifications 112, 113 (should be trap_type Clients)
	UPDATE notify_traps SET oid = '100.0.1' WHERE notification_id IN(112, 113);
END IF;

IF (current_revision < 43)
THEN
	-- Virtual client halted because of internal errors 
	-- Category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(121, 3, 'Virtual Client Halted',
	'The virtual client for %s has halted operations because %s',
	1, false, NULL, true, true, false, false, false);
	-- Process alert_source/trap_type (to distinguish from 112,113, Clients)
	INSERT INTO notify_alerts VALUES(121, 5);
	INSERT INTO notify_traps VALUES(121, 5, '100.0.5');

	-- Close alert, send trap
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(122, 3,
	'Resolve Notice of Halted Virtual Client',
	'The virtual client for %s is no longer halted and has resumed operations.',
	3, true, NULL, true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(122, 5);
	INSERT INTO notify_traps VALUES(122, 5, '100.0.5');
END IF;

IF (current_revision < 44)
THEN
	-- Virtual client halted because of internal errors 
	-- Category=Core
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(123, 3, 'Virtual Client Restores',
	'The virtual client for %s has halted operations because %s',
	1, false, NULL, true, false, false, true, false);
	-- Process alert_source/trap_type (to distinguish from 112,113, Clients)
	INSERT INTO notify_emails VALUES(123, 'Unattended Backup Information', 
	'MailTo', 'Instant Recovery Verification <root>',
	'Recovery Verification Failed',
	'Recovery verification of the virtual client for %s failed because %s.');
END IF;

IF (current_revision < 45)
THEN

-- fix oops above, end result should look like:
--INSERT INTO notifications VALUES(123, 3, 'Virtual Client Application Restore',
--'The virtual client %s with instance %s has halted operations because %s',
--1, false, NULL, false, false, true, false);

--INSERT INTO notify_emails VALUES(123, 'Unattended Backup Information', 
--'MailTo', 'Instant Recovery <root>',
--'Application Restore Failed',
--'Application restore of the virtual client %s with instance %s failed because %s.');

	UPDATE notifications SET
	short_description='Virtual Client Application Restore',
	primary_text='Application restore of the virtual client %s with instance %s failed because %s',
	alert='f', email='t', log='f'
	WHERE notification_id=123;

	UPDATE notify_emails SET
	from_name='Instant Recovery <root>',
	subject='Application Restore Failed',
	body='Application restore of the virtual client %s with instance %s failed because %s'
	WHERE notification_id=123;
END IF;

IF (current_revision < 46)
THEN
	-- category=Core, audit log only
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(124, 3, 'Successful login',
	'Successful login.  %s',
	3, true, NULL, false, false, false, true, false);
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(125, 3, 'Failed login',
	'Failed login attempt.  %s',
	3, true, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 47)
THEN
	UPDATE notifications
	SET primary_text = 'A File-Level Recovery image has existed for more than 3 days. You must unmount the image from any connected hosts, then tear it down in the RRC.'
	WHERE notification_id = 92;
END IF;

IF (current_revision < 48)
THEN
	UPDATE notifications
	SET primary_text = 'Disk space usage threshold exceeded. Disk %s is %s full (%s MB free). %s'
	WHERE notification_id = 12;

	UPDATE notifications SET short_description = 'System state has changed',
	primary_text = '%s: cannot connect to system database. %s' 
	WHERE notification_id = 14;

	UPDATE notifications SET short_description = 'System state has changed',
	primary_text = '%s: system database is now responding. %s'
	WHERE notification_id = 15;
	
	UPDATE notifications SET 
	primary_text = 'License: system license has expired.'
	WHERE notification_id = 20;
	UPDATE notify_emails
	SET body = 'Your Unitrends System license has expired.  Please renew your license by calling 888-374-6124.'
	WHERE notification_id = 20;

	UPDATE notifications SET
	primary_text = 'License Grace Period: The licensed capacity of this system has been exceeded.'
	WHERE notification_id = 23;

	UPDATE notifications SET
	primary_text = 'License Failure Notification: This system cannot perform backups because your data has exceeded the licensed capacity.'
	WHERE notification_id = 24;

	UPDATE notifications SET
	short_description = 'New user interface version available',
	primary_text = 'Update: Unitrends user interface version %s is available.',
	action = 'To install, go to Updates page in Settings->System, Updates, and Licensing.'
	where notification_id = 25;

	UPDATE notifications SET
	primary_text = 'License Alert: This system is at 70%% of its licensed capacity.'
	WHERE notification_id = 27;

	UPDATE notifications SET
	primary_text = 'License Warning (Yellow Alert): This system is at 80%% of its licensed capacity.'
	WHERE notification_id = 28;

	UPDATE notifications SET
	primary_text = 'Urgent License Warning (Red Alert): This system is at 90%% of its licensed capacity.  Backup failures are imminent.'
	WHERE notification_id = 29;

	UPDATE notifications SET
	primary_text = 'Retention: The system retention tool was unable to calculate the retention period.'
	WHERE notification_id = 30;

	UPDATE notifications SET
	primary_text = 'Retention: The system retention tool has not been initialized.'
	WHERE notification_id = 31;

	UPDATE notifications SET
	primary_text = 'Retention: The system retention tool initialization grace period has expired.'
	WHERE notification_id = 32;

	UPDATE notifications SET
	primary_text = 'A software update requires the system to be rebooted.',
	action = 'Go to Settings->System, Updates, and Licensing->Shutdown.'
	WHERE notification_id = 33;

	UPDATE notifications SET
	short_description = 'System Archiving state has changed'
	WHERE notification_id = 65;

	UPDATE notifications SET
	short_description = 'System Archiving state has changed'
	WHERE notification_id = 66;

	UPDATE notifications SET
	short_description = 'System Archiving state has changed'
	WHERE notification_id = 68;

	UPDATE notifications SET
	short_description = 'System Archiving state has changed'
	WHERE notification_id = 69;

	UPDATE notifications SET
	short_description = 'System Archiving state has changed'
	WHERE notification_id = 70;

	UPDATE notifications SET
	short_description = 'System Version',
	primary_text = 'System %s'
	WHERE notification_id = 71;

	UPDATE notifications
	SET short_description = 'Unitrends Agent Version Information',
	primary_text = '%s out of %s clients are running an outdated version of Unitrends Agent.',
	action = 'Please upgrade your Unitrends Agent.'
	WHERE notification_id = 88;

	UPDATE notifications
	SET primary_text = 'A File-Level Recovery image existed for over 4 days and was torn down automatically.'
	WHERE notification_id = 91;

	UPDATE notifications
	SET primary_text = 'A File-Level Recovery image has existed for more than 3 days. You must unmount the image from any connected hosts, then tear it down in the user interface.'
	WHERE notification_id = 92;

	UPDATE notifications
	SET short_description = 'System Overloaded',
	primary_text = 'System appears overloaded; a significant amount of processing delays have been seen over the past %s.  If this continues, you should consider either %s or decreasing the backups on this system.',
	action = NULL
	WHERE notification_id = 93;

	UPDATE notifications
	SET primary_text = 'The total amount of critical client data is approaching the system capacity.',
	action = 'Consider either purchasing another system to accommodate this critical data, or decreasing the amount of data protected by this system.'
	WHERE notification_id = 95;

	UPDATE notifications
	SET primary_text = 'License: System license will expire in 30 days.'
	WHERE notification_id = 97;
	UPDATE notify_emails 
	SET body = 'Your Unitrends System license will expire in 30 days. Please renew your license by calling 888-374-6124.'
	WHERE notification_id = 97;

	UPDATE notifications
	SET primary_text = 'License: System license will expire in 14 days.'
	WHERE notification_id = 98;
	UPDATE notify_emails 
	SET body = 'Your Unitrends System license will expire in 14 days. Please renew your license by calling 888-374-6124.'
	WHERE notification_id = 98;

	UPDATE notifications
	SET primary_text = 'License: System license will expire in 7 days.'
	WHERE notification_id = 99;
	UPDATE notify_emails 
	SET body = 'Your Unitrends System license will expire in 7 days. Please renew your license by calling 888-374-6124.'
	WHERE notification_id = 99;

	UPDATE notifications
	SET action = 'You need to purchase another system to accommodate this critical data, or reduce the amount of data protected by this system.'
	WHERE notification_id = 109;
	UPDATE notify_emails
	SET body = 'The total amount of critical client data (%s) has exceeded the maximum backup capacity (%s) of %s, and therefore operations such as deduplication have been turned off.  You need to purchase another system to accommodate this critical data, or reduce the amount of data protected by this system.\n\nPlease refer to the Capacity Report for details about the amount of maximum backup capacity consumed by individual clients.'
	WHERE notification_id = 109;

	UPDATE notifications
	SET primary_text =  'A VMware Instant Recovery session has existed for more than 3 days.  Please return to the Instant Recovery Job Status tool in the user interface and tear down the session.'
	WHERE notification_id = 114;
	UPDATE notify_emails
	SET body = 'A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended.  Please return to the user interface and use the "Instant Recovery Job Status" tool to tear down the session.'
	WHERE notification_id = 114;

	UPDATE trap_types SET trap_type = 'System state has changed'
	WHERE trap_type_id = 8;

	UPDATE trap_types SET trap_type = 'System Open Alerts Status'
	WHERE trap_type_id = 13;
END IF;

IF (current_revision < 49)
THEN
	UPDATE notifications
	SET action = 'Consider either acquiring another system to accommodate this critical data, or decreasing the amount of data protected by this system.'
	WHERE notification_id = 95;
END IF;

IF (current_revision < 50)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(126, 4, 'Registeration Required',
	'Thank you for downloading Unitrends Enterprise Backup. Please register your system by selecting the Register button in the upper right corner in the user interface.',
	2, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(127, 4, 'Registration Required',
	'Registration: To continue protecting your environment with Unitrends Enterprise Backup, please register the system within the next 24 hours. Please select the Register button in the upper right corner of the user interface to complete the registration',
	2, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(128, 4, 'License Expiration Approaching',
	'%s License: The %s license will expire in 1 day.  Please select the Upgrade button to purchase the product. The system will reset back to the Free Edition and remove all existing backups.',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(129, 4, 'License Expiration Approaching',
	'%s License: The %s license will expire in 2 days.  Please select the Upgrade button to purchase the product. After 2 days, the system will reset back to the Free Edition.',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(130, 4, 'License Expiration Approaching',
	'%s License: The %s license will expire in 3 days.  Please select the Upgrade button to purchase the product. After 3 days, the system will reset back to the Free Edition',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(131, 4, 'License Expiration Approaching',
	'%s License: The %s license will expire in 7 days. Please select the Upgrade button to purchase the product. After 7 days, the system will reset back to the Free Edition',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(132, 4, 'License Expiration Approaching',
	'%s License: The %s license will expire in 15 days.',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(133, 4, 'License Expiration Approaching',
	'Trial License: The trial license  unlocks unlimited data protection for 30 days',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(134, 4, 'License Expiration Approaching',
	'%s License: The %s license has expired. In 3 days all your backups will be removed and the system will revert back to the Free Edition.',
	1, false, 'Please see system e-mail.', true, true, true, false, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(135, 4, 'License Expiration Approaching',
	'NFR License: The NFR license  will expire in 30 days',
	1, false, 'Please see system e-mail.', true, true, true, false, false);

	INSERT INTO notify_alerts VALUES(126, 5);
	INSERT INTO notify_alerts VALUES(127, 5);
	INSERT INTO notify_alerts VALUES(128, 5);
	INSERT INTO notify_alerts VALUES(129, 5);
	INSERT INTO notify_alerts VALUES(130, 5);
	INSERT INTO notify_alerts VALUES(131, 5);
	INSERT INTO notify_alerts VALUES(132, 5);
	INSERT INTO notify_alerts VALUES(133, 5);
	INSERT INTO notify_alerts VALUES(134, 5);
	INSERT INTO notify_alerts VALUES(135, 5);

	INSERT INTO notify_traps VALUES(126, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(127, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(128, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(129, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(130, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(131, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(132, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(133, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(134, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(135, 5, '100.0.5');

	INSERT INTO notify_emails VALUES(126, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'Registraton Required',
	'Thank you for downloading Unitrends Enterprise Backup. Please register your system by selecting Register button in the upper right corner in the user interface.');

	INSERT INTO notify_emails VALUES(127, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'Registration Required',
	'Registration: To continue protecting your environment with Unitrends Enterprise Backup, please register the system within the next 24 hours. Please select the Register button in the upper right corner of the user interface to complete the registration.');

	INSERT INTO notify_emails VALUES(128, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The %s license for the system will expire in 1 day. Please upgrade the system by clicking Upgrade in the user interface. After 1 day, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. Warning: All backups on the system will be removed once the license is reverted back to the Free Edition.');

	INSERT INTO notify_emails VALUES(129, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The %s license for the system will expire in 2 days. Please upgrade the system by clicking Upgrade in the user interface. After 2 days, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. Warning: All backups on the system will be removed once the license is reverted back to the Free Edition.');

	INSERT INTO notify_emails VALUES(130, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The %s license for the system will expire in 3 days. Please upgrade the system by clicking Upgrade in the user interface. After 3 days, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. All backups on the system will be removed once the license is reverted back to the Free Edition.');

	INSERT INTO notify_emails VALUES(131, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The %s license for the system will expire in 7 days. Please upgrade the system by clicking Upgrade in the user interface. After 7 days, the system will revert back to the Free Edition, which enables protection for up to 4 virtual machines in your environment.');

	INSERT INTO notify_emails VALUES(132, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The %s license for the system will expire in 15 days. Please upgrade the system by clicking Upgrade in the user interface. After 15 days, the system will revert back to the Free Edition.');

	INSERT INTO notify_emails VALUES(133, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'Thank you for registering for the trial edition, enabling unlimited data protection for 30 days. To upgrade the product, please click the Upgrade button in the user interface.');

	INSERT INTO notify_emails VALUES(134, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'%s License: The %s license has expired. In 3 days all your backups will be removed and the system will revert back to the Free Edition.');

	INSERT INTO notify_emails VALUES(135, 'Unattended Backup Information',
	'MailTo', 'License Notifications <root>', 'License expiration approaching',
	'The NFR license for the system will expire in 30 days. Please upgrade the system by clicking Upgrade in the user interface. After 30 days, the system will revert back to the Free Edition.');

	
END IF;

IF (current_revision < 51)
THEN
	UPDATE notifications SET
	primary_text = 'License: system %s has expired.'
	WHERE notification_id = 20;

	UPDATE notify_emails
	SET body = 'Your Unitrends System %s has expired. %s'
	WHERE notification_id = 20;
END IF;

IF (current_revision < 52)
THEN
	UPDATE notifications
	SET primary_text = 'The total amount of critical client data is approaching the system capacity.  Consider either decreasing the amount of data protected by this system%s.',
	action = NULL
	WHERE notification_id = 95;
END IF;

IF (current_revision < 53)
THEN
	UPDATE notify_emails SET body = 'License Grace Period: The licensed capacity of this system has been exceeded. Usage above your current allowance is permitted for a grace period of 7 days (total).  Once this grace period expires, any attempt to perform backups to your system will automatically be denied.  Your grace period will expire in %s days.  %s'
	WHERE notification_id = 23;

	UPDATE notify_emails SET body = 'License Failure Notification:  The Total System Content being protected by this system has now exceeded the licensed capacity (%s GB).  The system is now unable to perform backups until you increase your licensed capacity.  This situation is critical.  Your data is no longer being protected.  %s'
	WHERE notification_id = 24;

	UPDATE notify_emails SET body = 'License Alert: The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 70%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected.  %s'
	WHERE notification_id = 27;

	UPDATE notify_emails SET body = 'License Warning (Yellow Alert): The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 80%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license.  %s'
	WHERE notification_id = 28;

	UPDATE notify_emails SET body = 'License Warning (Red Alert): The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 90%% of the licensed capacity.  You should immediately increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license, and this situation is imminent.  %s'
	WHERE notification_id = 29;

	-- #106 had multiple 'the' (Volumes on the the ...)
	UPDATE notify_emails SET body = 'Volumes on the client %s have changed.  The previous list of volumes was:\n %s\nThe current list is:\n %s\nFile-level schedules that include this client should be re-saved or modified to incorporate these changes.\n\nIf new volumes were added and should be included in backups, re-save the schedule(s) to automatically add the new volume(s).  If new volumes should not be backed up, add them to an exclusion list.\n\nIf volumes were permanently removed, re-save the schedule to automatically eliminate them from the backup profile.\n\nFile-level schedules that include this client:\n%s\n'
	WHERE notification_id = 106;

	UPDATE notify_emails SET body = 'Vault License Warning (Red Alert): The licensed vault capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 100%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all of your data is fully protected.  %s'
	WHERE notification_id = 86;

	UPDATE notify_emails SET body = 'Vault License Warning (Yellow Alert): The licensed vault capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents %s%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your vaulting will not run correctly if your data volume exceeds your vault license capacity.  %s'
	WHERE notification_id = 87;

	-- #31,32 are for demo license, no longer used, but change Data Protection Unit to system. 
	UPDATE notify_emails SET body = 'License Setup Grace Period Notification: The license for this system has not been initialized.  You must initialize your license within 30 days of upgrade or installation.  Once this grace period expires, any attempt to perform backups to your system will automatically be denied.  Your grace period will expire in %s days.  Please contact your authorized Unitrends partner or Unitrends Support Center immediately at 888-374-6124 to initialize your license properly and restart the process of protecting your data.'
	WHERE notification_id = 31;

	UPDATE notify_emails SET body = 'License Setup Grace Period Notification: The license for this system has not been initialized.  The system is now unable to perform backups until you initialize your license. This situation is critical.  Your data is no longer being protected.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to initialize your license and restart the process of protecting your data.'
	WHERE notification_id = 32;
END IF;

IF (current_revision < 54)
THEN
	UPDATE notifications SET short_description = 'Support Contract notice', 
	primary_text = 'Support Contract: your Support Contract %s. %s.',
	action = NULL WHERE notification_id = 36;

	UPDATE notifications SET short_description = 'Support Contract notice', 
	primary_text = 'Support Contract: your Support Contract expires on %s. %s.',
	action = NULL WHERE notification_id = 37;
END IF;

IF (current_revision < 55)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(136, 4, 'Schedule Event was Skipped',
	'An event for %s in schedule "%s" was skipped: %s %s backup was already queued or running.',
	2, false, NULL, false, true, false, true, false);
	INSERT INTO notify_traps VALUES(136, 10, '100.0.10');
END IF;

IF (current_revision < 56)
THEN
	---NOTE: Inserts for notifications table, columns are:
	---   notification_id, category_id, short_description, primary_text
	---   severity, state, action, alert, trap, email, log, psa

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(137, 2, 'MegaRaid state has changed',
	'MegaRaid %s status is%s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(138, 2, 'MegaRaid state has changed',
	'MegaRaid %s drive status is%s',
	1, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(139, 2, 'MegaRaid state has changed',
	'MegaRaid %s status is%s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(140, 2, 'MegaRaid state has changed',
	'MegaRaid %s drive status is%s',
	2, false, NULL, true, true, false, false, false);

	INSERT INTO notify_alerts VALUES(137, 2);
	INSERT INTO notify_alerts VALUES(138, 2);
	INSERT INTO notify_alerts VALUES(139, 2);
	INSERT INTO notify_alerts VALUES(140, 2);

	INSERT INTO notify_traps VALUES(137, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(138, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(139, 2, '100.0.2');
	INSERT INTO notify_traps VALUES(140, 2, '100.0.2');
END IF;

IF (current_revision < 57)
THEN
	UPDATE notifications SET primary_text = 'MegaRaid %s drive status is%s. Serial#%s'
	WHERE notification_id = 138 OR notification_id = 140;
END IF;

IF (current_revision < 58)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(141, 6, 'Agent upgrade available',
			'An agent upgrade is available for %s: Version %s', 3, false, 
			'To install, go to the Settings->Updates->Agent Updates.',
			true, true, false, true, false);
	
	INSERT INTO notify_alerts VALUES(141, 1);
	INSERT INTO notify_traps VALUES(141, 12, '100.0.12');
END IF; 

IF (current_revision < 59)
THEN
	UPDATE notifications SET primary_text = 'Agent %s is available for %s.', 
	action = 'To install, go to Settings->System, Updates, and Licensing->Updates->Agent Updates.'
	WHERE notification_id = 141;
END IF;

IF (current_revision < 60)
THEN
	-- Unresolved alert, trap, email, log
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(142, 5, 'System Metadata Backup Failure', '%s',
	1, false, NULL, true, true, true, true, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(143, 0, 'Internal notice', 'Resolve/Close alerts for system metadata',
	0, true, NULL, true, false, false, false, false);

	INSERT INTO notify_alerts VALUES(142, 10);
	INSERT INTO notify_alerts VALUES(143, 10);

	INSERT INTO notify_traps VALUES(142, 8, '100.0.5');

	INSERT INTO notify_emails VALUES(142, 'Unattended Backup Information',
			'MailTo', 'Backup Notification <root>',
			'System Metadata Backup Failure', '%s');
END IF;

IF (current_revision < 61)
THEN
	-- Repeating entry for BugId: 15016
	UPDATE notifications SET primary_text = 'Agent %s is available for %s.',
	action = 'To install, go to Settings->System, Updates, and Licensing->Updates->Agent Updates.'
	WHERE notification_id = 141;
	
	-- Close notification matching 141 solely for audit log. BugId: 15112
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(144, 6,'Resolve notice of agent upgrade available',
			'The agent on %s has been upgraded to version %s.', 3, true,
			NULL, false, false, false, true, false);
			
	UPDATE alerts SET closed=true WHERE closed=false AND source_id=1 AND notification_id=88 AND target='BP Version';
END IF;

IF (current_revision < 62)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(145, 8, 'Replication Backlog Notice',
	'Some backups have waited to replicate for over %s days.',
	2, false, 'Please go to Settings > Replication > Dashboard and remove backups from the queue as needed to reduce this backlog.',
	true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(145, 5);
	INSERT INTO notify_traps VALUES(145, 5, '100.0.5');
END IF;

IF (current_revision < 63)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(146, 4,
		'Backup owner changed for Replicated BareMetal restore',
		'%s backup %d changed ownership from %s client %s (id %d) to %s client %s (id %d).',
		3, true, NULL, false, false, false, true, false); 
END IF;

IF (current_revision < 64)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(147, 4, 'Retention Settings modified', 'Retention Settings for %s are modified from [ min = %d days, max = %d days ] to [ min = %d days, max = %d days ]',
		3, false, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 65)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(148, 4, 'Backup Share Unavailable', 'A backup/restore of client %s instance %s failed because an application share already exists.',
		1, false, ' Please check to see if an item restore share exists. If so, it will need to be torn down in order for backup/restore jobs to run.',
		true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(148, 10);
	INSERT INTO notify_traps VALUES(148, 10, '100.0.10');
END IF;

IF (current_revision < 66)
THEN
	UPDATE notifications SET action = 'Consider modifying the queue strategy to Recency, or remove backups from the queue as needed to reduce this backlog.'
	WHERE notification_id = 145;
END IF;

IF (current_revision < 67) 
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(149, 8, 'Replication queue scheme changed', 'Replication queue scheme changed from %s to %s', 3, true, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 68)
THEN
	UPDATE notifications SET primary_text = '%s' WHERE notification_id = 72;

	UPDATE notifications SET severity = 1 WHERE notification_id = 81;
END IF;

IF (current_revision < 69)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(150, 1, 'Application Instance discovered/protected',
		'%s', 3, false, NULL, false, true, false, false, false);

	INSERT INTO notify_traps VALUES(150, 12, '100.0.12');
END IF;

IF (current_revision < 70)
THEN
	INSERT INTO trap_types VALUES (15, 'Disk health state has changed');
        INSERT INTO alert_source VALUES (15, 'Disk Health');
        INSERT INTO categories VALUES (15, 'Disk Health');

--- State t means closed 0  and f means open 1
        UPDATE notifications
	  SET short_description='Disk health state has changed', primary_text = '%s', severity = 1, category_id = 15, log='t'
	WHERE notification_id = 137;

        UPDATE notifications
	  SET short_description='Disk health state has changed', primary_text = '%s', severity = 3, category_id = 15, log='t'
	WHERE notification_id = 138;

	UPDATE notifications
          SET short_description='Disk health trap is collected', primary_text = '%s', severity = 4, category_id=15, state='t', alert='f', trap='t', email='f', log='f'
	WHERE notification_id = 139;

	UPDATE notifications
          SET short_description='Internal notice', primary_text = 'Resolve/Close alerts for Disk Health source', category_id=0, severity =0, state='t', alert='t', trap='f', email='f', log='f'
	WHERE notification_id = 140;

        UPDATE notify_alerts
          SET source_id = 15
        WHERE notification_id = 137 OR notification_id = 138 OR notification_id = 139 OR notification_id = 140;  

        UPDATE notify_traps
          SET trap_type_id = 15, oid = '100.0.15'
        WHERE notification_id = 137 OR notification_id = 138 OR notification_id = 139 OR notification_id = 140;  

END IF;

IF (current_revision < 71)
THEN
	IF EXISTS (SELECT notification_id FROM notifications WHERE notification_id >= 151)
	THEN
		DELETE FROM notifications WHERE notification_id >= 151;
	END IF;

        INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(151, 4, 'VerifyHashes state has changed', '%s',
                1, false, 'Contact Support', true, true, true, false, false);

        INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(152, 4, 'Bad Hashes Found', '%s',
                1, false, NULL, false, true, false, true, false);

        INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(153, 4, 'Bad Hashes Found', '%s',
                1, false, 'Contact Support', true, true, true, false, false);

        INSERT INTO notify_alerts VALUES(151, 5);
        INSERT INTO notify_alerts VALUES(153, 5);

        INSERT INTO notify_traps VALUES(151, 5, '100.0.5');
        INSERT INTO notify_traps VALUES(152, 10, '100.0.10');
        INSERT INTO notify_traps VALUES(153, 10, '100.0.10');

        INSERT INTO notify_emails VALUES(151, 'Unattended Backup Information',
        'MailTo', 'Verify Hash Notification <root>', 'Verify Hash Tool Failed',
        '%s');
        INSERT INTO notify_emails VALUES(153, 'Unattended Backup Information',
        'MailTo', 'Verify Hash Notification <root>', 'Error/Warnings seen in verifyHashes log file',
        '%s');
END IF;

IF (current_revision < 72) 
THEN
	IF NOT EXISTS (SELECT notification_id FROM notifications WHERE notification_id = 149)
	THEN
		INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(149, 8, 'Replication queue scheme changed', 'Replication queue scheme changed from %s to %s',
			3, true, NULL, false, false, false, true, false);
	END IF;
END IF;

IF (current_revision < 73)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(154, 4, 'VMware Exclude modified', 'Disk "%s" is %s, for VM "%s"',
	3, false, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 74)
THEN
--      fix typo 
	UPDATE notifications SET short_description = 'Registration Required' 
	WHERE notification_id = 126;
--      add new IPMI notifications
	INSERT INTO trap_types VALUES (16, 'IPMI Event has occurred');
        INSERT INTO alert_source VALUES (16, 'IPMI Event');
        INSERT INTO categories VALUES (16, 'IPMI Event');

	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(155, 16, 'IPMI MIN Event', '"%s"', 
		3, false, NULL, true, true, true, false, false);
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(156, 16, 'IPMI MAJ Event', '"%s"', 
		2, false, NULL, true, true, true, false, false);
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(157, 16, 'IPMI CRT Event', '"%s"', 
		1, false, NULL, true, true, true, false, false);


        INSERT INTO notify_traps VALUES(155, 16, '100.0.16');
        INSERT INTO notify_traps VALUES(156, 16, '100.0.16');
        INSERT INTO notify_traps VALUES(157, 16, '100.0.16');

        INSERT INTO notify_alerts VALUES(155, 16);
        INSERT INTO notify_alerts VALUES(156, 16);
        INSERT INTO notify_alerts VALUES(157, 16);
        INSERT INTO notify_emails VALUES(155, 'Unattended Backup Information',
	'MailTo', 'IPMI Event Notifications <root>', 
	'An IPMI Minor Event has occurred', '%s');
        INSERT INTO notify_emails VALUES(156, 'Unattended Backup Information',
	'MailTo', 'IPMI Event Notifications <root>', 
	'An IPMI Major Event has occurred', '%s');
        INSERT INTO notify_emails VALUES(157, 'Unattended Backup Information',
	'MailTo', 'IPMI Event Notifications <root>', 
	'An IPMI Critical Event has occurred', '%s');

END IF;

IF (current_revision < 75)
THEN
--      fix severity 4 for Disk Health event
	UPDATE notifications SET severity = 3
	WHERE notification_id = 139;
--      fix notifications for IPMI events to turn off alerts, add clear
	UPDATE notifications SET alert='f'
	WHERE notification_id = 155;
	UPDATE notifications SET alert='f'
	WHERE notification_id = 156;
	UPDATE notifications SET alert='f'
	WHERE notification_id = 157;
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(158, 0, 'Internal notice',
		'Resolve/Clear alerts for IPMI events', 
		0, true, NULL, true, false, false, false, false);
END IF;

IF (current_revision < 76)
THEN
	INSERT INTO notify_alerts VALUES(158, 16);
END IF;

IF (current_revision < 77)
THEN


	INSERT INTO notify_psa VALUES (21,'CryptoDaemon process state has changed','Process: cryptoDaemon is required but not running.');
	INSERT INTO notify_psa VALUES (152,'Bad Hashes Found','%s');
	INSERT INTO notify_psa VALUES (53,'Backup failure','Scheduled backup did not run.  %s');
	INSERT INTO notify_psa VALUES (112,'Virtual Client Notice','You have been running client %s as a virtualized server on %s for 14 or more days.');
	INSERT INTO notify_psa VALUES (2,'3ware state has changed','3ware %s unit status changed %s');
	INSERT INTO notify_psa VALUES (3,'3ware state has changed','3ware %s drive status changed %s');
	INSERT INTO notify_psa VALUES (4,'3ware state has changed','3ware %s unit status changed %s');
	INSERT INTO notify_psa VALUES (5,'3ware state has changed','3ware %s drive status changed %s');
	INSERT INTO notify_psa VALUES (9,'Client state has changed','%s: client is no longer listening to connections. %s');
	INSERT INTO notify_psa VALUES (17,'PCI state has changed','PCI device has been disconnected: %s');
	INSERT INTO notify_psa VALUES (22,'CryptoDaemon process state has changed','Process: cryptoDaemon is required and running but has no master key.');
	INSERT INTO notify_psa VALUES (26,'Tasker process state has changed','Process: Tasker has been stopped.');
	INSERT INTO notify_psa VALUES (34,'Driver installation','unitrends-drivers has not been installed.  Will retry in 24 hours.');
	INSERT INTO notify_psa VALUES (35,'Migration process state has changed','Migration: long pathname migration %s');
	INSERT INTO notify_psa VALUES (41,'RAID state has changed','RAID drive status changed to offline. %s');
	INSERT INTO notify_psa VALUES (42,'RAID state has changed','RAID %s: Drive status %s');
	INSERT INTO notify_psa VALUES (43,'RAID state has changed','RAID %s: Array status %s ');
	INSERT INTO notify_psa VALUES (44,'RAID state has changed','RAID %s: Drive status %s');
	INSERT INTO notify_psa VALUES (45,'RAID state has changed','RAID %s: Array status %s ');
	INSERT INTO notify_psa VALUES (50,'CEP state has changed','CEP workspace %s has errors today.');
	INSERT INTO notify_psa VALUES (51,'CEP state has changed','Global Exchange log has errors today.');
	INSERT INTO notify_psa VALUES (54,'Backup failure','Master backup for client %s failed.');
	INSERT INTO notify_psa VALUES (56,'Backup failure','Selective backup for client %s failed.');
	INSERT INTO notify_psa VALUES (57,'Backup failure','SQL Server backup for client %s failed.');
	INSERT INTO notify_psa VALUES (58,'Restore failure','Restore for client %s failed.');
	INSERT INTO notify_psa VALUES (59,'Verification failure','Backup verify for client %s failed.');
	INSERT INTO notify_psa VALUES (60,'Backup failure','BareMetal backup for client %s failed.');
	INSERT INTO notify_psa VALUES (61,'Restore failure','BareMetal restore for client %s failed.');
	INSERT INTO notify_psa VALUES (62,'Backup failure','Backup operation for client %s failed.');
	INSERT INTO notify_psa VALUES (67,'SQL Server schedule skipped','SQL Server Instance %s on client %s will not perform scheduled backups for database %s because backups of type %s are not supported.');
	INSERT INTO notify_psa VALUES (74,'NIC Collisions','%s: %s');
	INSERT INTO notify_psa VALUES (75,'NIC Dropped Packets','%s: %s');
	INSERT INTO notify_psa VALUES (76,'NIC Errors','%s: %s');
	INSERT INTO notify_psa VALUES (77,'OpenVPN/Vaulting Status','OpenVPN not enabled while Vaulting is enabled');
	INSERT INTO notify_psa VALUES (79,'ArchiveDaemon process state has changed','Process: archiveDaemon is not running');
	INSERT INTO notify_psa VALUES (84,'External Storage status','External Storage: %s is Offline');
	INSERT INTO notify_psa VALUES (81,'SMART Information','%s');
	INSERT INTO notify_psa VALUES (55,'Backup failure','Differential backup for client %s failed.');
	INSERT INTO notify_psa VALUES (89,'3ware controller reset Alert','3ware reset AEN:cache synchronization failed, some data lost.');
	INSERT INTO notify_psa VALUES (94,'Backup Type Promotion','%s was promoted to %s for %s because %s.');
	INSERT INTO notify_psa VALUES (65,'System Archiving state has changed','Archive job %s is running.');
	INSERT INTO notify_psa VALUES (101,'Retention goal alert','%s has protection below minimum retention goal of %s days.');
	INSERT INTO notify_psa VALUES (102,'Retention limit alert','%s has protection above maximum retention limit of %s days.');
	INSERT INTO notify_psa VALUES (103,'Disaster Recovery failure alert','Disaster Recovery of %s');
	INSERT INTO notify_psa VALUES (108,'Storage Migration alert','%s mount point has been migrated to %s.');
	INSERT INTO notify_psa VALUES (137,'Disk health state has changed','%s');
	INSERT INTO notify_psa VALUES (113,'Virtual Client Notice','The virtual client for %s has been invalidated because %s.');
	INSERT INTO notify_psa VALUES (142,'System Metadata Backup Failure','%s');
	INSERT INTO notify_psa VALUES (117,'Virtual Failover Notice','Usage of the virtual failover area has exceeded %s%%, currently %s%% in use');
	INSERT INTO notify_psa VALUES (120,'Virtual Client Notice','The virtual client for %s has been deleted.');
	INSERT INTO notify_psa VALUES (121,'Virtual Client Halted','The virtual client for %s has halted operations because %s');
	INSERT INTO notify_psa VALUES (12,'Disk space usage warning','Disk space usage threshold exceeded. Disk %s is %s full (%s MB free). %s');
	INSERT INTO notify_psa VALUES (14,'System state has changed','%s: cannot connect to system database. %s');
	INSERT INTO notify_psa VALUES (25,'New user interface version available','Update: Unitrends user interface version %s is available.');
	INSERT INTO notify_psa VALUES (30,'Retention tool warning','Retention: The system retention tool was unable to calculate the retention period.');
	INSERT INTO notify_psa VALUES (33,'Reboot required','A software update requires the system to be rebooted.');
	INSERT INTO notify_psa VALUES (66,'System Archiving state has changed','Archive job %s is not running.');
	INSERT INTO notify_psa VALUES (68,'System Archiving state has changed','Archive media is at %s%% of capacity.');
	INSERT INTO notify_psa VALUES (69,'System Archiving state has changed','Archive media is at %s%% of capacity.');
	INSERT INTO notify_psa VALUES (88,'Unitrends Agent Version Information','%s out of %s clients are running an outdated version of Unitrends Agent.');
	INSERT INTO notify_psa VALUES (91,'File-Level Recovery Alert','A File-Level Recovery image existed for over 4 days and was torn down automatically.');
	INSERT INTO notify_psa VALUES (92,'File-Level Recovery Alert','A File-Level Recovery image has existed for more than 3 days. You must unmount the image from any connected hosts, then tear it down in the user interface.');
	INSERT INTO notify_psa VALUES (93,'System Overloaded','System appears overloaded; a significant amount of processing delays have been seen over the past %s.  If this continues, you should consider either %s or decreasing the backups on this system.');
	INSERT INTO notify_psa VALUES (95,'Growth of Critical Backup Data','The total amount of critical client data is approaching the system capacity.  Consider either decreasing the amount of data protected by this system%s.');
	INSERT INTO notify_psa VALUES (36,'Support Contract notice','Support Contract: your Support Contract %s. %s.');
	INSERT INTO notify_psa VALUES (136,'Schedule Event was Skipped','An event for %s in schedule \"%s\" was skipped: %s %s backup was already queued or running.');
	INSERT INTO notify_psa VALUES (148,'Backup Share Unavailable','A backup/restore of client %s instance %s failed because an application share already exists.');
	INSERT INTO notify_psa VALUES (145,'Replication Backlog Notice','Some backups have waited to replicate for over %s days.');
	INSERT INTO notify_psa VALUES (70,'Archive job completion','%s');
	INSERT INTO notify_psa VALUES (115,'Virtual Client Halted','The virtual client for %s has halted operations due to disk space shortage.  Please reallocate more space to virtual failover or delete a virtual client and try again.');
	INSERT INTO notify_psa VALUES (119,'Recovery Verification Failed','Recovery verification of the virtual client for %s failed because %s.');
	INSERT INTO notify_psa VALUES (123,'Application Restore Failed','Application restore of the virtual client %s with instance %s failed because %s');
	INSERT INTO notify_psa VALUES (97,'License expiration approaching','Your Unitrends System license will expire in 30 days. Please renew your license by calling 888-374-6124.');
	INSERT INTO notify_psa VALUES (98,'License expiration approaching','Your Unitrends System license will expire in 14 days. Please renew your license by calling 888-374-6124.');
	INSERT INTO notify_psa VALUES (99,'License expiration approaching','Your Unitrends System license will expire in 7 days. Please renew your license by calling 888-374-6124.');
	INSERT INTO notify_psa VALUES (109,'Growth of Critical Backup Data','The total amount of critical client data (%s) has exceeded the maximum backup capacity (%s) of %s, and therefore operations such as deduplication have been turned off.  You need to purchase another system to accommodate this critical data, or reduce the amount of data protected by this system.\n\nPlease refer to the Capacity Report for details about the amount of maximum backup capacity consumed by individual clients.');
	INSERT INTO notify_psa VALUES (114,'WARNING: VMware Instant Recovery session still active','A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended.  Please return to the user interface and use the \"Instant Recovery Job Status\" tool to tear down the session.');
	INSERT INTO notify_psa VALUES (126,'Registraton Required','Thank you for downloading Unitrends Enterprise Backup. Please register your system by selecting Register button in the upper right corner in the user interface.');
	INSERT INTO notify_psa VALUES (127,'Registration Required','Registration: To continue protecting your environment with Unitrends Enterprise Backup, please register the system within the next 24 hours. Please select the Register button in the upper right corner of the user interface to complete the registration.');
	INSERT INTO notify_psa VALUES (128,'License expiration approaching','The %s license for the system will expire in 1 day. Please upgrade the system by clicking Upgrade in the user interface. After 1 day, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. Warning: All backups on the system will be removed once the license is reverted back to the Free Edition.');
	INSERT INTO notify_psa VALUES (129,'License expiration approaching','The %s license for the system will expire in 2 days. Please upgrade the system by clicking Upgrade in the user interface. After 2 days, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. Warning: All backups on the system will be removed once the license is reverted back to the Free Edition.');
	INSERT INTO notify_psa VALUES (130,'License expiration approaching','The %s license for the system will expire in 3 days. Please upgrade the system by clicking Upgrade in the user interface. After 3 days, the system will reset back to the Free Edition, which enables protection for up to 4 virtual machines in your environment. All backups on the system will be removed once the license is reverted back to the Free Edition.');
	INSERT INTO notify_psa VALUES (131,'License expiration approaching','The %s license for the system will expire in 7 days. Please upgrade the system by clicking Upgrade in the user interface. After 7 days, the system will revert back to the Free Edition, which enables protection for up to 4 virtual machines in your environment.');
	INSERT INTO notify_psa VALUES (132,'License expiration approaching','The %s license for the system will expire in 15 days. Please upgrade the system by clicking Upgrade in the user interface. After 15 days, the system will revert back to the Free Edition.');
	INSERT INTO notify_psa VALUES (133,'License expiration approaching','Thank you for registering for the trial edition, enabling unlimited data protection for 30 days. To upgrade the product, please click the Upgrade button in the user interface.');
	INSERT INTO notify_psa VALUES (134,'License expiration approaching','%s License: The %s license has expired. In 3 days all your backups will be removed and the system will revert back to the Free Edition.');
	INSERT INTO notify_psa VALUES (135,'License expiration approaching','The NFR license for the system will expire in 30 days. Please upgrade the system by clicking Upgrade in the user interface. After 30 days, the system will revert back to the Free Edition.');
	INSERT INTO notify_psa VALUES (20,'License has expired.','Your Unitrends System %s has expired. %s');
	INSERT INTO notify_psa VALUES (23,'FATAL: License grace period.','License Grace Period: The licensed capacity of this system has been exceeded. Usage above your current allowance is permitted for a grace period of 7 days (total).  Once this grace period expires, any attempt to perform backups to your system will automatically be denied.  Your grace period will expire in %s days.  %s');
	INSERT INTO notify_psa VALUES (24,'FATAL: License has expired.','License Failure Notification:  The Total System Content being protected by this system has now exceeded the licensed capacity (%s GB).  The system is now unable to perform backups until you increase your licensed capacity.  This situation is critical.  Your data is no longer being protected.  %s');
	INSERT INTO notify_psa VALUES (27,'WARNING: License threshold exceeded.','License Alert: The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 70%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected.  %s');
	INSERT INTO notify_psa VALUES (28,'WARNING: License threshold exceeded.','License Warning (Yellow Alert): The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 80%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license.  %s');
	INSERT INTO notify_psa VALUES (153,'Error/Warnings seen in verifyHashes log file','%s');
	INSERT INTO notify_psa VALUES (156,'An IPMI Major Event has occurred','%s');
	INSERT INTO notify_psa VALUES (157,'An IPMI Critical Event has occurred','%s');
	INSERT INTO notify_psa VALUES (29,'WARNING: License threshold exceeded.','License Warning (Red Alert): The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 90%% of the licensed capacity.  You should immediately increase your license to ensure that all your data is fully protected.  Your backups will not run correctly if your data volume exceeds your license, and this situation is imminent.  %s');
	INSERT INTO notify_psa VALUES (106,'Client volumes have changed','Volumes on the client %s have changed.  The previous list of volumes was:\n %s\nThe current list is:\n %s\nFile-level schedules that include this client should be re-saved or modified to incorporate these changes.\n\nIf new volumes were added and should be included in backups, re-save the schedule(s) to automatically add the new volume(s).  If new volumes should not be backed up, add them to an exclusion list.\n\nIf volumes were permanently removed, re-save the schedule to automatically eliminate them from the backup profile.\n\nFile-level schedules that include this client:\n%s\n');
	INSERT INTO notify_psa VALUES (86,'Fatal: Vault License threshold exceeded.','Vault License Warning (Red Alert): The licensed vault capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents greater than 100%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all of your data is fully protected.  %s');
	INSERT INTO notify_psa VALUES (87,'WARNING: Vault License threshold exceeded.','Vault License Warning (Yellow Alert): The licensed vault capacity of this system is %s GB, and your Total System Content being protected is now %s GB.  This represents %s%% of the licensed capacity.  Many customers experience growth in data volume of as much as 100%% per year, which means it''s becoming urgent that you increase your license to ensure that all your data is fully protected.  Your vaulting will not run correctly if your data volume exceeds your vault license capacity.  %s');
	INSERT INTO notify_psa VALUES (31,'WARNING: License setup grace period.','License Setup Grace Period Notification: The license for this system has not been initialized.  You must initialize your license within 30 days of upgrade or installation.  Once this grace period expires, any attempt to perform backups to your system will automatically be denied.  Your grace period will expire in %s days.  Please contact your authorized Unitrends partner or Unitrends Support Center immediately at 888-374-6124 to initialize your license properly and restart the process of protecting your data.');
	INSERT INTO notify_psa VALUES (32,'FATAL: License setup grace period has expired.','License Setup Grace Period Notification: The license for this system has not been initialized.  The system is now unable to perform backups until you initialize your license. This situation is critical.  Your data is no longer being protected.  Please contact your authorized Unitrends partner or Unitrends representative immediately at 888-374-6124 to initialize your license and restart the process of protecting your data.');
	INSERT INTO notify_psa VALUES (151,'Verify Hash Tool Failed','%s');
	UPDATE notifications SET psa= true WHERE notification_id=21 OR notification_id=152 OR notification_id=53 OR notification_id=112 OR notification_id=2 OR notification_id=3 OR notification_id=4 OR notification_id=5 OR notification_id=9 OR notification_id=17 OR notification_id=22 OR notification_id=26 OR notification_id=34 OR notification_id=35 OR notification_id=41 OR notification_id=42 OR notification_id=43 OR notification_id=44 OR notification_id=45 OR notification_id=50 OR notification_id=51 OR notification_id=54 OR notification_id=56 OR notification_id=57 OR notification_id=58 OR notification_id=59 OR notification_id=60 OR notification_id=61 OR notification_id=62 OR notification_id=67 OR notification_id=74 OR notification_id=75 OR notification_id=76 OR notification_id=77 OR notification_id=79 OR notification_id=84 OR notification_id=81 OR notification_id=55 OR notification_id=89 OR notification_id=94 OR notification_id=65 OR notification_id=101 OR notification_id=102 OR notification_id=103 OR notification_id=108 OR notification_id=137 OR notification_id=113 OR notification_id=142 OR notification_id=117 OR notification_id=120 OR notification_id=121 OR notification_id=12 OR notification_id=14 OR notification_id=25 OR notification_id=30 OR notification_id=33 OR notification_id=66 OR notification_id=68 OR notification_id=69 OR notification_id=88 OR notification_id=91 OR notification_id=92 OR notification_id=93 OR notification_id=95 OR notification_id=36 OR notification_id=136 OR notification_id=148 OR notification_id=145 OR notification_id=70 OR notification_id=115 OR notification_id=119 OR notification_id=123 OR notification_id=97 OR notification_id=98 OR notification_id=99 OR notification_id=109 OR notification_id=114 OR notification_id=126 OR notification_id=127 OR notification_id=128 OR notification_id=129 OR notification_id=130 OR notification_id=131 OR notification_id=132 OR notification_id=133 OR notification_id=134 OR notification_id=135 OR notification_id=20 OR notification_id=23 OR notification_id=24 OR notification_id=27 OR notification_id=28 OR notification_id=153 OR notification_id=156 OR notification_id=157 OR notification_id=29 OR notification_id=106 OR notification_id=86 OR notification_id=87 OR notification_id=31 OR notification_id=32 OR notification_id=151;

END IF;

IF (current_revision < 78)
THEN
        INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(159, 5, 'Create recovery image',
				'Created image for %s recovery of %s backup of %s.',
				3, false, NULL, false, false, false, true, false);
        INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(160, 5, 'Tear-down recovery image',
				'Tore down recovery image (%s).',
				3, false, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 79)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(161, 4, 'Legal Hold Settings modified', 'Legal Hold Settings for %s are modified from [ %s ] to [ %s ]',
		3, false, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 80)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(162, 4, 'Legal Hold Backup(s) deleted', 'The following legal hold backup(s) for %s (%s) were deleted: %s',
		3, false, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 81)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(163, 4, 'Legal Hold Settings modified', 'Legal Hold Settings for following backup(s) of %s modified to [ %s ]: %s',
		3, false, NULL, false, false, false, true, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(164, 0, 'Internal notice', 'Resolve/Close alerts for Legal Hold alert source',
		0, true, NULL, true, false, false, false, false);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(165, 4, 'Legal Hold Backup Failure', 'Backup [%s, %s] for %s on legal hold has failed.',
		1, false, 'Please see system e-mail', true, true, true, false, false);

	INSERT INTO notify_alerts VALUES(164, 12);
	INSERT INTO notify_alerts VALUES(165, 12);

	INSERT INTO notify_traps VALUES(165, 10, '100.0.10');
        
	INSERT INTO notify_emails VALUES(165, 'Unattended Backup Information', 'MailTo', 'Backup Notification <root>',
		'Legal Hold Backup Failure', 'Backup [%s, %s] for %s, configured to have legal hold %s, has failed because of insufficient space on %s device.\nPlease consider resizing the device or revisit the legal hold configuration.');
END IF;

IF (current_revision < 82)
THEN
--      fix notifications for IPMI events to turn off email
        UPDATE notifications SET email='f' WHERE notification_id = 155;
	UPDATE notifications SET email='f' WHERE notification_id = 156;
	UPDATE notifications SET email='f' WHERE notification_id = 157;
END IF;

IF (current_revision < 83)
THEN
	IF NOT EXISTS (SELECT notification_id FROM notifications WHERE notification_id = 166)
	THEN
		INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
		VALUES(166, 8, 'Duplicate Source Identities Detected', 'Replication target has multiple sources configured with the same identity',
		1, false, NULL, false, true, false, false, false);
		INSERT INTO notify_traps VALUES(166, 8, '100.0.8');
	END IF;
END IF;

IF (current_revision < 84)
THEN
	UPDATE notifications SET log=true WHERE notification_id
	IN(64,78,90,101,102,118,124,125,136,137,138,141,142,144,146,147,149,152,154,159,160,161,162,163)
	AND log=false;

	UPDATE notifications SET psa=false WHERE notification_id
	IN(64,78,90,118,124,125,141,144,146,147,149,154,159,160,161,162,163)
	AND psa=true;
END IF;

IF (current_revision < 85)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(167, 4, 'Empty Schedule Detected',
	'There are no instances assigned for protection in the following schedule(s): %s',
	3, false, 'Either add instances to the schedule, or delete the schedule.',
	true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(167, 1);
	INSERT INTO notify_traps VALUES(167, 1, '100.0.1');
END IF;

IF (current_revision < 86)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(168, 6, 'Incomplete Update Detected', 'Duplicate %s packages were detected on this Appliance. *Needs further review*',
		1, false, NULL, false, true, false, true, false);

	INSERT INTO notify_traps VALUES(168, 5, '100.0.5');
END IF;

IF (current_revision < 87)
THEN
	UPDATE notifications
	SET primary_text='System Version Information %s'
	WHERE notification_id = 71;

	UPDATE notifications
	SET primary_text='Duplicate packages were detected on this Appliance (*Needs further review*): %s'
	WHERE notification_id = 168;
END IF;

IF (current_revision < 88)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(169, 2, 'Footprint Report Information', 'Footprint Report Notification for %s',
		3, false, NULL, false, false, true, false, false);

	INSERT INTO notify_emails VALUES(169, 'Unattended Backup Information',
		'MailTo', 'Footprint Report Notification <root>', 'Footprint Report Complete', '%s');
END IF;

IF (current_revision < 89)
THEN
	-- bug #20061: add onDemand traps using type 20
	-- types 17-19 are available for future use
	INSERT INTO categories (category_id,category) VALUES (20, 'onDemand');
	INSERT INTO trap_types (trap_type_id, trap_type) VALUES (20, 'onDemand');
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(170, 20, 'onDemandTrap', 'onDemandTrap', 
		3, true, 'onDemandTrap', false, true, false, true, false);
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES (170,20,'100.0.20');
END IF;

IF (current_revision < 90)
THEN
        -- Hyper-V Instant Recovery
        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(171, 5, 'Instant Recovery Alert',
        'A Hyper-V Instant Recovery session has existed for more than 3 days.  Please return to the Instant Recovery interface Job Status in the user interface and tear down the session.',
        2, false, NULL, true, true, true, false, false);

        INSERT INTO notify_alerts VALUES(171, 6);

        INSERT INTO notify_emails VALUES(171, 'Unattended Backup Information',
        'MailTo', 'Restore Notifications <root>', 'WARNING: Hyper-V Instant Recovery session still active',
        'A Hyper-V Instant Recovery session has existed for more than 3 days.  Extended use of the Hyper-V Instant Recovery feature is not recommended.  Please return to the user interface and use the "Instant Recovery Job Status" tool to tear down the session.');

        INSERT INTO notify_traps VALUES(171, 1, '100.0.6');
END IF;

IF (current_revision < 91)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(172, 6, 'Manually closed alert',
		'The following alert was closed by a user operation: [ %s ]',
		3, true, NULL, false, false, false, true, false);
END IF;

IF (current_revision < 92)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(173, 3, 'Inventory Sync Warning',
		'Inventory full sync completed with %d warning(s).',
		2, false, NULL, true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(173, 5);
	INSERT INTO notify_traps VALUES(173, 5, '100.0.5');

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(174, 3, 'Inventory Sync was Terminated',
		'Inventory sync was terminated. %s.',
		1, false, NULL, true, true, false, false, false);
	INSERT INTO notify_alerts VALUES(174, 5);
	INSERT INTO notify_traps VALUES(174, 5, '100.0.5');
END IF;

IF (current_revision < 93)
THEN
	INSERT INTO notifications (notification_id, category_id, short_description,
		primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(175, 4, 'Metadata Check', 'Metadata Check: %s',
		1, false, NULL, true, true, false, false, false);

	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(175, 8, '100.0.8');
	INSERT INTO notify_alerts (notification_id, source_id) VALUES(175, 8);
END IF;

IF (current_revision < 94)
THEN
  	-- bug #20272: add traps for good backups
	INSERT INTO notifications (notification_id, category_id, short_description,
 		primary_text, severity, state, action, alert, trap, email, log, psa)
 	VALUES(176, 4, 'Successful Backup', 'Backup completed: %s.',
 		3, false, NULL, false, true, false, false, false);
 	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(176, 10, '100.0.10');
END IF;

IF (current_revision < 95)
THEN
	-- correction of email bodies and missing psa
	INSERT INTO notify_psa VALUES (171,'WARNING: Hyper-V Instant Recovery session still active','A Hyper-V Instant Recovery session has existed for more than 3 days.  Extended use of the Hyper-V Instant Recovery feature is not recommended.  Please return to the user interface and use the \"Instant Recovery interface\" tool to tear down the session.');
	UPDATE notify_psa
	SET long_description = 'A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended.  Please return to the user interface and use the \"Instant Recovery interface\" tool to tear down the session.'
	where notification_id=114;
	UPDATE notifications
	SET primary_text = 'A VMware Instant Recovery session has existed for more than 3 days.  Please return to the Instant Recovery interface tool in the RRC and tear down the session.'
	WHERE notification_id=114;
	UPDATE notify_emails
	SET body='A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended.  Please return to the RRC and use the "Instant Recovery interface" tool to tear down the session.'
	where notification_id=114;
	UPDATE notifications
    SET primary_text = 'A Hyper-V Instant Recovery session has existed for more than 3 days.  Please return to the Instant Recovery interface tool in the RRC and tear down the session.',psa=true
    WHERE notification_id=171;
    UPDATE notify_emails
    SET body='A Hyper-V Instant Recovery session has existed for more than 3 days.  Extended use of the Hyper-V Instant Recovery feature is not recommended.  Please return to the RRC and use the "Instant Recovery interface" tool to tear down the session.'
    where notification_id=171;
END IF;

IF (current_revision < 96)
Then
	-- Add alternate notifications for CE
        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(177, 4, 'Backup failure','Whoops! Your scheduled backup did not run. %s',2,false,'Visit the Community Edition forum for help, how to''s, and resources.',false,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(178, 4, 'Backup failure','Whoops! Your master backup for client %s failed.',2,false,'Visit the Community Edition forum for help, how to''s, and resources.',false,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(179, 4, 'Backup failure','Whoops! Your differential backup for client %s failed.',2,false,'Visit the Community Edition forum for help, how to''s, and resources.',false,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(180, 4, 'Backup failure','Whoops! Your selective backup for client %s failed.',2,false,'Visit the Community Edition forum for help, how to''s, and resources.',false,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(181, 4, 'Backup failure','Whoops! Your backup operation for client %s failed.',2,false,'Visit the Community Edition forum for help, how to''s, and resources.',false,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(182, 2, 'Disk space usage warning','Your disk space usage threshold has been exceeded. Disk %s is %s full(%s MB free). %s',2,false,'Need help creating a more efficient backup strategy? Contact a backup specialist at info@unitrends.com',true,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(183, 4, 'Growth of Critical Backup Data','Your total critical data is approaching system capacity.',2,false,'Need help creating a more efficient backup strategy? Contact a backup specialist at info@unitrends.com',true,true,false,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(184, 4, 'Licensed capacity warning','Uh,oh! Your system is at 70% of licensed capacity.',2,false,'Need help creating a more efficient backup strategy? Contact a backup specialist at info@unitrends.com',true,true,true,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(185, 4, 'Licensed capacity warning','Uh,oh! Your system is at 80% of licensed capacity.',2,false,'Need help creating a more efficient backup strategy? Contact a backup specialist at info@unitrends.com',true,true,true,false,true);

        INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(186, 4, 'Licensed capacity warning','Uh,oh! Your system is at 90% of licensed capacity.',2,false,'Need help creating a more efficient backup strategy? Contact a backup specialist at info@unitrends.com',true,true,true,false,true);

	INSERT INTO notifications (notification_id, category_id, short_description,
	primary_text, severity, state, action, alert, trap, email, log, psa)
	VALUES(187, 6, 'New user interface version available', 'Update: Unitrends user interface version %s is available.', 2, false, 'To install the available updates, go to Options > Check for Updates.',true,true,false,false,true);

        INSERT INTO notify_emails VALUES(184, 'Unattended Backup Information','MailTo','License Notifcation <root>','WARNING:License threshold exceeded',
        'The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB. This represents greater than 70%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected. %s');

        INSERT INTO notify_emails VALUES(185, 'Unattended Backup Information','MailTo','License Notification <root>','WARNING:License threshold exceeded',
        'The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB. This represents greater than 80%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected. %s');

        INSERT INTO notify_emails VALUES(186, 'Unattended Backup Information','MailTo','License Notification <root>','WARNING:License threshold exceeded',
        'The licensed capacity of this system is %s GB, and your Total System Content being protected is now %s GB. This represents greater than 90%% of the licensed capacity. Many customers experience growth in data volume of as much as 100%% per year, which means you may soon need to increase your license to ensure that all your data is fully protected. %s');

        INSERT INTO notify_alerts VALUES(182, 6);
        INSERT INTO notify_alerts VALUES(183, 8);
        INSERT INTO notify_alerts VALUES(184, 8);
        INSERT INTO notify_alerts VALUES(185, 8);
        INSERT INTO notify_alerts VALUES(186, 8);
	INSERT INTO notify_alerts VALUES(187, 5);

	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(177, 10, '100.0.10');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(178, 10, '100.0.10');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(179, 10, '100.0.10');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(180, 10, '100.0.10');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(181, 10, '100.0.10');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(182, 6, '100.0.6');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(183, 8, '100.0.8');
        INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(184, 8, '100.0.8');
        INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(185, 8, '100.0.8');
        INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(186, 8, '100.0.8');
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(187, 5, '100.0.5');

	INSERT INTO notify_psa VALUES (187, 'New user interface version available', 'Update: Unitrends user interface version %s is available.');

END IF;

IF (current_revision < 97)
Then
	-- Instant recovery generic message change
        UPDATE notifications
        SET primary_text = 'A VMware Instant Recovery session has existed for more than 3 days. Please return to the Instant Recovery interface in the user interface and tear down the session.'
        WHERE notification_id=114;
		
	UPDATE notifications
	SET primary_text = 'A Hyper-V Instant Recovery session has existed for more than 3 days. Please return to the Instant Recovery interface in the user interface and tear down the session.',psa=true
	WHERE notification_id=171;
	
	UPDATE notify_emails
        SET body='A VMware Instant Recovery session has existed for more than 3 days.  Extended use of the VMware Instant Recovery feature is not recommended. Please return to the Instant Recovery interface in the user interface and tear down the session.'
        where notification_id=114;
		
	UPDATE notify_emails
	SET body='A Hyper-V Instant Recovery session has existed for more than 3 days.  Extended use of the Hyper-V Instant Recovery feature is not recommended. Please return to the Instant Recovery interface in the user interface and tear down the session.'
	where notification_id=171;
END IF;

IF (current_revision < 98)
then
	-- Add alert for storage change
	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(188, 4, 'Storage Allocation', 'Storage Allocation for Backup has changed', 3, false, NULL,true,true,false,false,false);

	INSERT INTO notify_alerts VALUES(188, 8);
		 
	INSERT INTO notify_traps (notification_id, trap_type_id, oid) VALUES(188, 8, '100.0.8');
END IF;

IF (current_revision < 99)
THEN
	-- Metadata check action and log changes.
	UPDATE notifications
	SET action='Contact Support', log=true
	WHERE notification_id=175;
END IF;

IF (current_revision < 100)
THEN
	-- Add alert for CE agent install location
	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(190, 6, 'Agent upgrade available',
        'An agent upgrade is available for %s: Version %s', 3, false,
        'To install this upgrade, open File Explorer and enter the following path to access the new agent: \\<ip_address_of_CE>\windows_agent .',
        true, true, false, true, false);

        INSERT INTO notify_alerts VALUES(190, 1);
        INSERT INTO notify_traps VALUES(190, 12, '100.0.12');
		
	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(191, 6,'Resolve notice of agent upgrade available',
        'The agent on %s has been upgraded to version %s.', 3, true,
        NULL, false, false, false, true, false);

END IF;

IF (current_revision < 101)
THEN
        -- enable audit for 188
        UPDATE notifications
	SET log=true
	WHERE notification_id=188;
END IF;

IF (current_revision < 102)
THEN

	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(192, 4, 'License Expiration Approaching',
        'Unitrends License: The Unitrends license will expire in 1 days.',
        1, false, 'Please see system e-mail.', true, true, true, false, false);
		
	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(193, 4, 'License Expiration Approaching',
        'Unitrends License: The Unitrends license will expire in 15 days.',
        1, false, 'Please see system e-mail.', true, true, true, false, false);
	
	INSERT INTO notifications (notification_id, category_id, short_description,
        primary_text, severity, state, action, alert, trap, email, log, psa)
        VALUES(194, 4, 'License Expiration Approaching',
        'Unitrends License: The Unitrends license will expire in 30 days.',
        1, false, 'Please see system e-mail.', true, true, true, false, false);
	
	INSERT INTO notify_alerts VALUES(192, 5);
	INSERT INTO notify_alerts VALUES(193, 5);
	INSERT INTO notify_alerts VALUES(194, 5);
		
	INSERT INTO notify_traps VALUES(192, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(193, 5, '100.0.5');
	INSERT INTO notify_traps VALUES(194, 5, '100.0.5');
		
	INSERT INTO notify_emails VALUES(192, 'Unattended Backup Information',
        'MailTo', 'License Notifications <root>', 'License expiration approaching',
        'The Unitrends license for the system will expire in 1 days.');
	
	INSERT INTO notify_emails VALUES(193, 'Unattended Backup Information',
        'MailTo', 'License Notifications <root>', 'License expiration approaching',
        'The Unitrends license for the system will expire in 15 days.');
	
	INSERT INTO notify_emails VALUES(194, 'Unattended Backup Information',
        'MailTo', 'License Notifications <root>', 'License expiration approaching',
        'The Unitrends license for the system will expire in 30 days.');

END IF;

IF (current_revision <103)
THEN
	UPDATE notifications
	SET action='Visit the Unitrends Free forum for help, how to''s, and resources.'
	WHERE notification_id in (177,178,179,180,181);
	
	UPDATE notifications
	SET action='To install this upgrade, open File Explorer and enter the following path to access the new agent: \\ip_address_of_Unitrends_Free\windows_agent .'
	Where notification_id=190;

END IF;

--- Add next revision block here
--	IF (current_revision < new_rev)
--	THEN
--		SQL statements for new_rev
--	END IF;

--- Finalize the notification_mgmt record
	UPDATE notification_mgmt SET revision = new_rev, status = update_status;

    -- bug #19527: put GUC settings back to defaults
    IF (sqlConformUserContext)
    THEN
        EXECUTE 'set standard_conforming_strings = '|| sqlConformString;
        EXECUTE 'set escape_string_warning = '|| escStringWarning;
    END IF;
    --RAISE NOTICE 'AFTER: standard_conforming_strings=% escape_string_warning=%', sqlConformString, escStringWarning;

RETURN TRUE;
END$BODY$
LANGUAGE 'plpgsql' VOLATILE;

SELECT update_notifications();
DROP FUNCTION update_notifications();

