<?php
# This queries the database for data to send to the vault and sends it up,
# formatted as XML.  It will send the current list of all entity IDs (to
# handle deletion of stale/gone data, i.e. removed backups), and will send
# complete data for all entities created after the latest sync time... use
# discretion about that though.  For example, a backup may be in-progress
# during a sync, then no updates could be sent in the next sync to reflect
# any new status.

require_once 'logger.php';
require 'feed_generator.php';
initialize_log('statussync');
$date_string = date('r');
logger(4, '=============================================================='."\n".'==============================================================');
logger(1, 'StatusSync feed requested at '.time().': '.$date_string);
$err = 'Could not process request, see statussync log for details';

// master.ini stuff
$cmd_bppath = 'eval `grep BPDIR /etc/default/bp.ini`';
$cmd_master_ini = 'MASTER_INI=$BPDIR/bpinit/master.ini';
$cmd_bputil = 'BPUTIL=$BPDIR/bin/bputil';
$cmd_ini = "$cmd_bppath; $cmd_master_ini; $cmd_bputil";

// setup
$retval = bp_bypass_cookie(3);
if ($retval === false) {
	$error = 'Could not bypass cookie: '.bp_error();
	logger(0, $error);
	echo $err;
	exit(1);
}
register_shutdown_function("bp_destroy_cookie");

// first make sure that output is enabled, otherwise send nothing
$enabled = false;
$cmd_enabled = '$BPUTIL -g "StatusSync" "EnableOutput" "no" $MASTER_INI';
$enabled_output = trim(shell_exec("$cmd_ini; $cmd_enabled"));
if (strtolower($enabled_output{0}) == 'y' ||
    strtolower($enabled_output{0}) == 't' ||
    $enabled_output == 1) {
	$enabled = true;
}
if ($enabled == false) {
	logger(0, 'Status synchronization is disabled');
	echo $err;
	exit(1);
}

// next check secure transfer settings and status
$cmd_allow_insecure = '$BPUTIL -g "StatusSync" "AllowInsecureTransfer" "no" $MASTER_INI';
$allow_insecure_output = trim(shell_exec("$cmd_ini; $cmd_allow_insecure"));
if (strtolower($allow_insecure_output{0}) == 'y' ||
    strtolower($allow_insecure_output{0}) == 't' ||
    $allow_insecure_output == 1) {
	$allow_insecure = true;
} else {
	$allow_insecure = false;
}
if ($allow_insecure == false) {
	if ((!isset($_SERVER['HTTPS'])) or (empty($_SERVER['HTTPS']))) {
		logger(0, 'SSL is required for status data transmission');
		echo $err;
		exit(1);
	}
}

// get amount of days to send from master.ini
$default_output_days = 31;
$cmd_days = '$BPUTIL -g "StatusSync" "OutputDays" "' . $default_output_days . '" $MASTER_INI';
$output_days_output = trim(shell_exec("$cmd_ini; $cmd_days"));
if (is_numeric($output_days_output)) {
	$output_days = intval($output_days_output);
} else {
	logger(5, 'Invalid or unset output days value in configuration file');
	$output_days = $default_output_days;
}
logger(3, "Number of days to return: $output_days");
$output_cutoff_time = time() - ($output_days * 86400);
//echo "$output_cutoff_time cutoff, time is ".time()." with output_days $output_days\n";

// gotten from post/get/whatever
$latest_sync_time = 0;
if (isset($_REQUEST['latest_time']) and is_numeric($_REQUEST['latest_time'])) {
	$latest_sync_time = pg_escape_string($_REQUEST['latest_time']);
}
logger(4, "Last sync time was $latest_sync_time");


start_feed($feed);

// metadata
logger(5, 'Adding metadata queries');
$query = "SELECT '" . time() . "' as time;";
add_query('metadata', $query, $feed);


// alerts - send latest
logger(5, 'Adding alert queries');
$query = <<<EOSQL
	SELECT alert_id
	FROM bp.alerts
	WHERE (updated > '$output_cutoff_time')
EOSQL;
add_query('alert_ids', $query, $feed);
$query = <<<EOSQL
	SELECT alert_id, created, source_id, source_name, closed, severity, alert_text, updated
	FROM bp.alerts INNER JOIN bp.alert_source USING (source_id)
	WHERE (updated >= '$latest_sync_time') AND (updated > '$output_cutoff_time')
EOSQL;
add_query('alerts', $query, $feed);


// nodes - send the whole current list
logger(5, 'Adding client queries');
$query = <<<EOSQL
	SELECT node_no, node_name, priority, status, properties, type, os
	FROM bp.nodes
EOSQL;
add_query('nodes', $query, $feed);


// backups - send latest, add buffer for complete data for recent backups
logger(5, 'Adding backup queries');
$query = <<<EOSQL
	SELECT backup_no
	FROM bp.backups
	WHERE start_time > '$output_cutoff_time'
	AND tape_no != 4294967295
EOSQL;
add_query('backup_ids', $query, $feed);
// somehow need to figure out what's still in progress, not just start_time
$query = <<<EOSQL
	SELECT backup_no, node_no, start_time, elapsed_time, job_no, total_netpaths, total_megs, status, exit_code, type, properties
	FROM bp.backups
	WHERE (start_time > ('$latest_sync_time' - 86400)) AND (start_time > '$output_cutoff_time')
	AND tape_no != 4294967295
EOSQL;
add_query('backups', $query, $feed);


// sds - send all necessary (we have no PK to go by, perhaps fix this later)
logger(5, 'Adding SDS queries');
$query = <<<EOSQL
	SELECT sds_stats.backup_no, sync_type, presync_seconds, sync_seconds, postsync_seconds, done_epoch, bytes_syncd, message
	FROM bp.sds_stats, bp.backups
	WHERE (done_epoch > ('$latest_sync_time' - 86400)) AND (done_epoch > '$output_cutoff_time')
	AND sds_stats.backup_no = backups.backup_no
	AND backups.tape_no != 4294967295
EOSQL;
add_query('sds', $query, $feed);


// sql_backups - send all necessary based on backups sent
logger(5, 'Adding SQL queries');
$query = <<<EOSQL
	SELECT sql.sql_ref, sql.node_no, sql.database_name, sql.server_instance_name, sql.group_file_order, sql.file_order_no, sql.sql_type
	FROM bp.sql_backups AS sql, bp.backups AS b
	WHERE sql.sql_ref = b.backup_no
	AND (b.start_time > ('$latest_sync_time' - 86400)) AND (b.start_time > '$output_cutoff_time')
	AND b.tape_no != 4294967295
EOSQL;
add_query('sql', $query, $feed);


finish_feed($feed);

$date_string = date('r');
logger(1, 'StatusSync feed finished at '.time().': '.$date_string);
logger(5, 'Exiting from script');
exit (0);
?> 
